#!/usr/bin/env python2
# import argparse
"""
This modules purpose is to test bqtoolls

"""
from __future__ import print_function
import bqtools
import unittest
from deepdiff import DeepDiff 
import difflib
import pprint
import copy
import logging

from google.cloud import bigquery


class testScannerMethods(unittest.TestCase):
    def setUp(self):

        logging.basicConfig()
        

        self.pp = pprint.PrettyPrinter(indent=4)
        # test 1 validate can create a schema from a dictionary
        self.schemaTest1 = {
                "string":"a string",
                "integer":0,
                "float":36.3,
                "boolean":False,
                "record": {
                        "string2":"another string",
                        "integer2":3,
                        "float":3.1415926,
                        "boolean2":True
                        },
                "array":[
                        {"string3":"yet another string",
                         "integer3":32}
                    ]
            }
        self.schemaTest2 = {
            "string":"a string",
            "integer":0,
            "record": {
                    "string2":"another string",
                    "float":3.1415926,
                    "boolean2":True,
                    "appended1":"String 3"
                    },
            "array":[
                    {
                    "string3":"yet another string",
                    "integer3":32,
                    "foo":1.0
                    }
                ],
            "anotherarray":[ {"test1":1,"test2":True}
                    ]
            }

        # next  schemas are for testing bare array handling
        # this is a starting schema
        self.schema2startnobare = {
            "string": "a string",
            "integer": 0,
            "record": {
                "string2": "another string",
                "float": 3.1415926,
                "boolean2": True,
                "appended1": "String 3"
            },
            "array": [
                {
                    "string3": "yet another string",
                    "integer3": 32,
                    "foo": 1.0
                }
            ]
        }
        # this adds 2 bare arrays
        self.schemaTest2bare = {
            "string": "a string",
            "integer": 0,
            "record": {
                "string2": "another string",
                "float": 3.1415926,
                "boolean2": True,
                "appended1": "String 3"
            },
            "array": [
                {
                    "string3": "yet another string",
                    "integer3": 32,
                    "foo": 1.0
                }
            ],
            "stringarray": ["test1","test2","test3"],
            "intarray": [1,2,3],
            "mixArray":[{"a":"hello"},{"b":"hi","d":"foo"},{"c":100}]
        }
        # resultant schema and objects shoulld loook like this
        self.schemaTest2nonbare = {
            "string": "a string",
            "integer": 0,
            "record": {
                "string2": "another string",
                "float": 3.1415926,
                "boolean2": True,
                "appended1": "String 3"
            },
            "array": [
                {
                    "string3": "yet another string",
                    "integer3": 32,
                    "foo": 1.0
                }
            ],
            "stringarray": [{"value":"test1"}],
            "intarray": [{"value":1}],
            "mixArray":[{"a":"hello","b":"hi","c":100,"d":"foo"}]
        }
            
        self.schemaTest4={
                  "name": "",
                  "description": "",
                  "initialNodeCount": 0,
                  "nodeConfig": {
                      "machineType": "",
                      "diskSizeGb": 0,
                      
                      "oauthScopes": [
                        {"scope":""}
                      ],
                      "serviceAccount": "",
                      "metadata": [
                        {"key":"","value":""}
                      ],
                      "imageType": "",
                      "labels": [
                         {"key":"","value":""}
                       ],
                      "localSsdCount": 0,
                      "tags": [
                        {"tag":""}
                      ],
                      "preemptible": False,
                      "accelerators": [
                        {
                          "acceleratorCount": "",
                          "acceleratorType": ""
                        }
                      ]
                    },
                  "masterAuth": {
                      "username": "",
                      "password": "",
                      "clientCertificateConfig": {
                          "issueClientCertificate": False,
                        },
                      "clusterCaCertificate": "",
                      "clientCertificate": "",
                      "clientKey": "",
                    },
                  "loggingService": "",
                  "monitoringService": "",
                  "network": "",
                  "clusterIpv4Cidr": "",
                  "addonsConfig": {
                      "httpLoadBalancing": {
                          "disabled": False,
                        },
                      "horizontalPodAutoscaling": {
                          "disabled": False,
                        },
                      "kubernetesDashboard": {
                          "disabled": False,
                        },
                      "networkPolicyConfig": {
                              "disabled": False,
                        }
                    },
                  "subnetwork": "",
                  "nodePools": [
                    {
                      "name": "",
                      "config": {
                          "machineType": "",
                          "diskSizeGb": 0,
                          "minCpuPlatform":"",
                          "oauthScopes": [
                            {"scope":""}
                          ],
                          "serviceAccount": "",
                          "metadata": [
                            {"key":"","value":""}
                          ],
                          "imageType": "",
                          "labels": [
                             {"key":"","value":""}
                           ],
                          "localSsdCount": 0,
                          "tags": [
                            {"tag":""}
                          ],
                          "preemptible": False,
                          "accelerators": [
                            {
                              "acceleratorCount": "",
                              "acceleratorType": "",
                            }
                          ]
                        },
                      "initialNodeCount": 0,
                      "selfLink": "",
                      "version": "",
                      "instanceGroupUrls": [
                        {"uri":""}
                      ],
                      "status": "",
                      "statusMessage": "",
                      "autoscaling": {
                          "enabled": False,
                          "minNodeCount": 0,
                          "maxNodeCount": 0
                        },
                      "management": {
                          "autoUpgrade": False,
                          "autoRepair": False,
                          "upgradeOptions": {
                              "autoUpgradeStartTime": "",
                              "description": "",
                            }
                        },
                    }
                  ],
                  "locations": [
                    {'location':''}
                  ],
                  "enableKubernetesAlpha": False,
                  "resourceLabels": [
                         {"key":"","value":""}
                       ],
                  "labelFingerprint": "",
                  "legacyAbac": {
                      "enabled": False,
                    },
                  "networkPolicy": {
                      "provider": "",
                      "enabled": False,
                    },
                  "ipAllocationPolicy": {
                      "useIpAliases": False,
                      "createSubnetwork": False,
                      "subnetworkName": "",
                      "clusterIpv4Cidr": "",
                      "nodeIpv4Cidr": "",
                      "servicesIpv4Cidr": "",
                      "clusterSecondaryRangeName": "",
                      "servicesSecondaryRangeName": "",
                      "clusterIpv4CidrBlock": "",
                      "nodeIpv4CidrBlock": "",
                      "servicesIpv4CidrBlock": ""
                    },
                  "masterAuthorizedNetworksConfig": {
                      "enabled": False,
                      "cidrBlocks": [
                        {
                          "displayName": "",
                          "cidrBlock": "",
                        }

                      ],
                    },
                  "selfLink": "",
                  "zone": "",
                  "endpoint": "",
                  "initialClusterVersion": "",
                  "currentMasterVersion": "",
                  "currentNodeVersion": "",
                  "createTime": "",
                  "status": "",
                  "statusMessage": "",
                  "nodeIpv4CidrSize": 0,
                  "servicesIpv4Cidr": "",
                  "instanceGroupUrls": [
                    {"uri":""}
                  ],
                  "currentNodeCount": 0,
                  "expireTime": "",
            }
    
        self.schemaTest3={
                  "name": "",
                  "description": "",
                  "initialNodeCount": 0,
                  "nodeConfig": {
                      "machineType": "",
                      "diskSizeGb": 0,
                      
                      "oauthScopes": [
                        {"scope":""}
                      ],
                      "serviceAccount": "",
                      "metadata": [
                        {"key":"","value":""}
                      ],
                      "imageType": "",
                      "labels": [
                         {"key":"","value":""}
                       ],
                      "localSsdCount": 0,
                      "tags": [
                        {"tag":""}
                      ],
                      "preemptible": False,
                      "accelerators": [
                        {
                          "acceleratorCount": "",
                          "acceleratorType": ""
                        }
                      ]
                    },
                  "masterAuth": {
                      "username": "",
                      "password": "",
                      "clientCertificateConfig": {
                          "issueClientCertificate": False,
                        },
                      "clusterCaCertificate": "",
                      "clientCertificate": "",
                      "clientKey": "",
                    },
                  "loggingService": "",
                  "monitoringService": "",
                  "network": "",
                  "clusterIpv4Cidr": "",
                  "addonsConfig": {
                      "httpLoadBalancing": {
                          "disabled": False,
                        },
                      "horizontalPodAutoscaling": {
                          "disabled": False,
                        },
                      "kubernetesDashboard": {
                          "disabled": False,
                        },
                      "networkPolicyConfig": {
                              "disabled": False,
                        }
                    },
                  "subnetwork": "",
                  "nodePools": [
                    {
                      "name": "",
                      "config": {
                          "machineType": "",
                          "diskSizeGb": 0,
                          "oauthScopes": [
                            {"scope":""}
                          ],
                          "serviceAccount": "",
                          "metadata": [
                            {"key":"","value":""}
                          ],
                          "imageType": "",
                          "labels": [
                             {"key":"","value":""}
                           ],
                          "localSsdCount": 0,
                          "tags": [
                            {"tag":""}
                          ],
                          "preemptible": False,
                          "accelerators": [
                            {
                              "acceleratorCount": "",
                              "acceleratorType": "",
                            }
                          ]
                        },
                      "initialNodeCount": 0,
                      "selfLink": "",
                      "version": "",
                      "instanceGroupUrls": [
                        {"uri":""}
                      ],
                      "status": "",
                      "statusMessage": "",
                      "autoscaling": {
                          "enabled": False,
                          "minNodeCount": 0,
                          "maxNodeCount": 0
                        },
                      "management": {
                          "autoUpgrade": False,
                          "autoRepair": False,
                          "upgradeOptions": {
                              "autoUpgradeStartTime": "",
                              "description": "",
                            }
                        },
                    }
                  ],
                  "locations": [
                    {'location':''}
                  ],
                  "enableKubernetesAlpha": False,
                  "resourceLabels": [
                         {"key":"","value":""}
                       ],
                  "labelFingerprint": "",
                  "legacyAbac": {
                      "enabled": False,
                    },
                  "networkPolicy": {
                      "provider": "",
                      "enabled": False,
                    },
                  "ipAllocationPolicy": {
                      "useIpAliases": False,
                      "createSubnetwork": False,
                      "subnetworkName": "",
                      "clusterIpv4Cidr": "",
                      "nodeIpv4Cidr": "",
                      "servicesIpv4Cidr": "",
                      "clusterSecondaryRangeName": "",
                      "servicesSecondaryRangeName": "",
                      "clusterIpv4CidrBlock": "",
                      "nodeIpv4CidrBlock": "",
                      "servicesIpv4CidrBlock": ""
                    },
                  "masterAuthorizedNetworksConfig": {
                      "enabled": False,
                      "cidrBlocks": [
                        {
                          "displayName": "",
                          "cidrBlock": "",
                        }

                      ],
                    },
                  "selfLink": "",
                  "zone": "",
                  "endpoint": "",
                  "initialClusterVersion": "",
                  "currentMasterVersion": "",
                  "currentNodeVersion": "",
                  "createTime": "",
                  "status": "",
                  "statusMessage": "",
                  "nodeIpv4CidrSize": 0,
                  "servicesIpv4Cidr": "",
                  "instanceGroupUrls": [
                    {"uri":""}
                  ],
                  "currentNodeCount": 0,
                  "expireTime": "",
            }
        self.monsterSchema = {"kind": "bigquery#table",
 "scanner": {"scantime": 1503036900327.313},
 "labels": [{"value": "",
 "key": ""}],
 "creationTime": "1502784475401",
 "tableReference": {"projectId": "gbm-finance-poc",
 "tableId": "testavro7",
 "datasetId": "pocDataSet1"},
 "numRows": "0",
 "numBytes": "0",
 "etag": "\"U174L-uZHiGsoJvSMZ_oqpuY9e8/MTUwMjc4NDQ3NTQwMQ\"",
 "numLongTermBytes": "0",
 "lastModifiedTime": "1502784475401",
 "type": "TABLE",
 "id": "gbm-finance-poc:pocDataSet1.testavro7",
 "selfLink": "https://www.googleapis.com/bigquery/v2/projects/gbm-finance-poc/datasets/pocDataSet1/tables/testavro7",
 "schema": {"fields": [{"type": "STRING",
		 "name": "id",
		 "mode": "NULLABLE"},
		 {"fields": [{"type": "STRING",
			 "name": "assetClassScheme",
			 "mode": "NULLABLE"},
			 {"type": "STRING",
			 "name": "keyValue",
			 "mode": "REQUIRED"}],
		 "type": "RECORD",
		 "name": "primaryAssetClass",
		 "mode": "NULLABLE"},
		 {"fields": [{"type": "STRING",
				 "name": "assetClassScheme",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
		 "type": "RECORD",
		 "name": "secondaryAssetClass",
		 "mode": "REPEATED"},
		 {"fields": [{"type": "STRING",
				 "name": "productTypeScheme",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
		 "type": "RECORD",
		 "name": "productType",
		 "mode": "REPEATED"},
		 {"fields": [{"type": "STRING",
				 "name": "productIdScheme",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
		 "type": "RECORD",
		 "name": "productId",
		 "mode": "REPEATED"},
		 {"fields": [{"type": "STRING",
				 "name": "assetClassScheme",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
		 "type": "RECORD",
		 "name": "assetClass",
		 "mode": "REPEATED"},
		 {"fields": [{"type": "STRING",
				 "name": "href",
				 "mode": "REQUIRED"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
		 "type": "RECORD",
		 "name": "buyerPartyReference",
		 "mode": "REQUIRED"},
			 {"fields": [{"type": "STRING",
				 "name": "href",
				 "mode": "REQUIRED"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
		 "type": "RECORD",
		 "name": "buyerAccountReference",
		 "mode": "NULLABLE"},
		 {"fields": [{"type": "STRING",
				 "name": "href",
				 "mode": "REQUIRED"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
		 "type": "RECORD",
		 "name": "sellerPartyReference",
		 "mode": "REQUIRED"},
		 {"fields": [{"type": "STRING",
				 "name": "href",
				 "mode": "REQUIRED"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
		 "type": "RECORD",
		 "name": "sellerAccountReference",
		 "mode": "NULLABLE"},
		 {"type": "STRING",
		 "name": "optionType",
		 "mode": "REQUIRED"},
			 {"fields": [{"fields": [{"type": "STRING",
			 "name": "id",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "href",
				 "mode": "REQUIRED"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "payerPartyReference",
			 "mode": "REQUIRED"},
			 {"fields": [{"type": "STRING",
				 "name": "href",
				 "mode": "REQUIRED"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "payerAccountReference",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "href",
				 "mode": "REQUIRED"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "receiverPartyReference",
			 "mode": "REQUIRED"},
			 {"fields": [{"type": "STRING",
				 "name": "href",
				 "mode": "REQUIRED"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "receiverAccountReference",
			 "mode": "NULLABLE"},
			 {"fields": [{"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
					 "name": "currencyScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "currency",
				 "mode": "REQUIRED"},
				 {"type": "FLOAT",
				 "name": "amount",
				 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_NonNegativeMoney_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "amount",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_NotionalAmount_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "amount",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "payoutStyle",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "standardSettlementStyle",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
							 "name": "settlementMethodScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "settlementMethod",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"fields": [{"type": "STRING",
							 "name": "routingIdCodeScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "routingId",
							 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingIds",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "routingName",
								 "mode": "REQUIRED"},
								 {"fields": [{"fields": [{"type": "STRING",
											 "name": "streetLine",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "streetAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "city",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "state",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "countryScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "country",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "postalCode",
										 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "routingAddress",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingAccountNumber",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingReferenceText",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingExplicitDetails",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "routingIdCodeScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "routingId",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "routingIds",
								 "mode": "REPEATED"},
								 {"type": "STRING",
								 "name": "routingName",
								 "mode": "REQUIRED"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "streetLine",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "streetAddress",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "city",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "state",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "countryScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "country",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "postalCode",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "routingAddress",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingAccountNumber",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingReferenceText",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingIdsAndExplicitDetails",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "correspondentPartyReference",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "correspondentInformation",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"fields": [{"type": "STRING",
								 "name": "routingIdCodeScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "routingId",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingIds",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "routingName",
								 "mode": "REQUIRED"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "streetLine",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "streetAddress",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "city",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "state",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "countryScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "country",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "postalCode",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "routingAddress",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingAccountNumber",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingReferenceText",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingExplicitDetails",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "routingIdCodeScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "routingId",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "routingIds",
								 "mode": "REPEATED"},
								 {"type": "STRING",
								 "name": "routingName",
								 "mode": "REQUIRED"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "streetLine",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "streetAddress",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "city",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "state",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "countryScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "country",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "postalCode",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "routingAddress",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingAccountNumber",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingReferenceText",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingIdsAndExplicitDetails",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "intermediarySequenceNumber",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "intermediaryPartyReference",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "intermediaryInformation",
						 "mode": "REPEATED"},
						 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "routingIdCodeScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "routingId",
									 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingIds",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "routingName",
								 "mode": "REQUIRED"},
								 {"fields": [{"fields": [{"type": "STRING",
											 "name": "streetLine",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "streetAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "city",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "state",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "countryScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "country",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "postalCode",
										 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "routingAddress",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingAccountNumber",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingReferenceText",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingExplicitDetails",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "routingIdCodeScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "routingId",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "routingIds",
								 "mode": "REPEATED"},
								 {"type": "STRING",
								 "name": "routingName",
								 "mode": "REQUIRED"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "streetLine",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "streetAddress",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "city",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "state",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "countryScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "country",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "postalCode",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "routingAddress",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingAccountNumber",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingReferenceText",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingIdsAndExplicitDetails",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "beneficiaryPartyReference",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "beneficiaryBank",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"fields": [{"type": "STRING",
									 "name": "routingIdCodeScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "routingId",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingIds",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "routingName",
								 "mode": "REQUIRED"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "streetLine",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "streetAddress",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "city",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "state",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
									 "name": "countryScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "country",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "postalCode",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "routingAddress",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingAccountNumber",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingReferenceText",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingExplicitDetails",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "routingIdCodeScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "routingId",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "routingIds",
								 "mode": "REPEATED"},
								 {"type": "STRING",
								 "name": "routingName",
								 "mode": "REQUIRED"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "streetLine",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "streetAddress",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "city",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "state",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "countryScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "country",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "postalCode",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "routingAddress",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingAccountNumber",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "routingReferenceText",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "routingIdsAndExplicitDetails",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "beneficiaryPartyReference",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "beneficiary",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "depositoryPartyReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Money_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "spreadConversionFactor",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "quantityUnitScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "spreadUnit",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_CommoditySpread_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "stepDate",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "stepValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "step",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_CalculationAmount_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "splitSettlementAmount",
							 "mode": "REQUIRED"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "routingIdCodeScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "routingId",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "routingIds",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "routingName",
									 "mode": "REQUIRED"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "streetLine",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "streetAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "city",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "state",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "countryScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "country",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "postalCode",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "routingAddress",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "routingAccountNumber",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "routingReferenceText",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "routingExplicitDetails",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"fields": [{"type": "STRING",
											 "name": "routingIdCodeScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "routingId",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingIds",
									 "mode": "REPEATED"},
									 {"type": "STRING",
									 "name": "routingName",
									 "mode": "REQUIRED"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "streetLine",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "streetAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "city",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "state",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "countryScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "country",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "postalCode",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "routingAddress",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "routingAccountNumber",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "routingReferenceText",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "routingIdsAndExplicitDetails",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "beneficiaryBank",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "routingIdCodeScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "routingId",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "routingIds",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "routingName",
									 "mode": "REQUIRED"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "streetLine",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "streetAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "city",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "state",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "countryScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "country",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "postalCode",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "routingAddress",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "routingAccountNumber",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "routingReferenceText",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "routingExplicitDetails",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"fields": [{"type": "STRING",
											 "name": "routingIdCodeScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "routingId",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingIds",
									 "mode": "REPEATED"},
									 {"type": "STRING",
									 "name": "routingName",
									 "mode": "REQUIRED"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "streetLine",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "streetAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "city",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "state",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "countryScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "country",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "postalCode",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "routingAddress",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "routingAccountNumber",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "routingReferenceText",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "routingIdsAndExplicitDetails",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "beneficiary",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "splitSettlement",
						 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "settlementInstruction",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "settlementInformation",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_FxOptionPayout_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "amount",
					 "mode": "REQUIRED"},
					 {"type": "INTEGER",
					 "name": "calculationPeriodNumberOfDays",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "valueDate",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_FutureValueAmount_value",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "paymentAmount",
			 "mode": "REQUIRED"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "unadjustedDate",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "dateAdjustments",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "adjustedDate",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "adjustableDate",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Offset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Period_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodSkip",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "unadjustedFirstDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "unadjustedLastDate",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_DateRange_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "unadjustedFirstDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "unadjustedLastDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_BusinessDateRange_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "scheduleBounds",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_RelativeDates_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "relativeDateAdjustments",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "relativeDate",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "paymentDate",
			 "mode": "REQUIRED"},
			 {"type": "STRING",
			 "name": "premiumType",
			 "mode": "NULLABLE"},
			 {"fields": [{"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "amount",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_Money_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "amount",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "spreadConversionFactor",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "quantityUnitScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "spreadUnit",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_CommoditySpread_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "amount",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "stepDate",
						 "mode": "REQUIRED"},
						 {"type": "FLOAT",
						 "name": "stepValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "step",
					 "mode": "REPEATED"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_CalculationAmount_value",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "pricePerOption",
			 "mode": "NULLABLE"},
			 {"type": "FLOAT",
			 "name": "percentageOfNotional",
			 "mode": "NULLABLE"},
			 {"type": "FLOAT",
			 "name": "discountFactor",
			 "mode": "NULLABLE"},
			 {"fields": [{"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "amount",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_Money_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "amount",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "spreadConversionFactor",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "quantityUnitScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "spreadUnit",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_CommoditySpread_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "amount",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "stepDate",
						 "mode": "REQUIRED"},
						 {"type": "FLOAT",
						 "name": "stepValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "step",
					 "mode": "REPEATED"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_CalculationAmount_value",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "presentValueAmount",
			 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_Premium_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "payerPartyReference",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "payerAccountReference",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "receiverPartyReference",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "receiverAccountReference",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Currency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "currency",
						 "mode": "REQUIRED"},
						 {"type": "FLOAT",
						 "name": "amount",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_NonNegativeMoney_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Currency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "currency",
						 "mode": "REQUIRED"},
						 {"type": "FLOAT",
						 "name": "amount",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_NotionalAmount_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Currency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "currency",
						 "mode": "REQUIRED"},
						 {"type": "FLOAT",
						 "name": "amount",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "payoutStyle",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "standardSettlementStyle",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "settlementMethodScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "settlementMethod",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"fields": [{"type": "STRING",
											 "name": "routingIdCodeScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "routingId",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingIds",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "routingName",
										 "mode": "REQUIRED"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "streetLine",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "streetAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "city",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "state",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "countryScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "country",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "postalCode",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "routingAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingAccountNumber",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingReferenceText",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingExplicitDetails",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"fields": [{"type": "STRING",
												 "name": "routingIdCodeScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "routingId",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "routingIds",
										 "mode": "REPEATED"},
										 {"type": "STRING",
										 "name": "routingName",
										 "mode": "REQUIRED"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "streetLine",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "streetAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "city",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "state",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "countryScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "country",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "postalCode",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "routingAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingAccountNumber",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingReferenceText",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingIdsAndExplicitDetails",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "correspondentPartyReference",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "correspondentInformation",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"fields": [{"type": "STRING",
											 "name": "routingIdCodeScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "routingId",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingIds",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "routingName",
										 "mode": "REQUIRED"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "streetLine",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "streetAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "city",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "state",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "countryScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "country",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "postalCode",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "routingAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingAccountNumber",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingReferenceText",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingExplicitDetails",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"fields": [{"type": "STRING",
												 "name": "routingIdCodeScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "routingId",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "routingIds",
										 "mode": "REPEATED"},
										 {"type": "STRING",
										 "name": "routingName",
										 "mode": "REQUIRED"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "streetLine",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "streetAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "city",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "state",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "countryScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "country",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "postalCode",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "routingAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingAccountNumber",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingReferenceText",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingIdsAndExplicitDetails",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "intermediarySequenceNumber",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "intermediaryPartyReference",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "intermediaryInformation",
								 "mode": "REPEATED"},
								 {"fields": [{"fields": [{"fields": [{"type": "STRING",
											 "name": "routingIdCodeScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "routingId",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingIds",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "routingName",
										 "mode": "REQUIRED"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "streetLine",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "streetAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "city",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "state",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "countryScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "country",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "postalCode",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "routingAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingAccountNumber",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingReferenceText",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingExplicitDetails",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"fields": [{"type": "STRING",
												 "name": "routingIdCodeScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "routingId",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "routingIds",
										 "mode": "REPEATED"},
										 {"type": "STRING",
										 "name": "routingName",
										 "mode": "REQUIRED"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "streetLine",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "streetAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "city",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "state",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "countryScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "country",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "postalCode",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "routingAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingAccountNumber",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingReferenceText",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingIdsAndExplicitDetails",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "beneficiaryPartyReference",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "beneficiaryBank",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"fields": [{"type": "STRING",
											 "name": "routingIdCodeScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "routingId",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingIds",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "routingName",
										 "mode": "REQUIRED"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "streetLine",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "streetAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "city",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "state",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "countryScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "country",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "postalCode",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "routingAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingAccountNumber",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingReferenceText",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingExplicitDetails",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"fields": [{"type": "STRING",
												 "name": "routingIdCodeScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "routingId",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "routingIds",
										 "mode": "REPEATED"},
										 {"type": "STRING",
										 "name": "routingName",
										 "mode": "REQUIRED"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "streetLine",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "streetAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "city",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "state",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "countryScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "country",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "postalCode",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "routingAddress",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingAccountNumber",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "routingReferenceText",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "routingIdsAndExplicitDetails",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "beneficiaryPartyReference",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "beneficiary",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "depositoryPartyReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "currencyScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_Currency_value",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "currencyScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "currency",
											 "mode": "REQUIRED"},
											 {"type": "FLOAT",
											 "name": "amount",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Money_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "currencyScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_Currency_value",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "currencyScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "currency",
											 "mode": "REQUIRED"},
											 {"type": "FLOAT",
											 "name": "amount",
											 "mode": "REQUIRED"},
											 {"type": "FLOAT",
											 "name": "spreadConversionFactor",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "quantityUnitScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "spreadUnit",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_CommoditySpread_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "currencyScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_Currency_value",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "currencyScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "currency",
											 "mode": "REQUIRED"},
											 {"type": "FLOAT",
											 "name": "amount",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "stepDate",
												 "mode": "REQUIRED"},
												 {"type": "FLOAT",
												 "name": "stepValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "step",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_CalculationAmount_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "splitSettlementAmount",
									 "mode": "REQUIRED"},
									 {"fields": [{"fields": [{"fields": [{"type": "STRING",
												 "name": "routingIdCodeScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "routingId",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "routingIds",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "routingName",
											 "mode": "REQUIRED"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "streetLine",
													 "mode": "REPEATED"}],
												 "type": "RECORD",
												 "name": "streetAddress",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "city",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "state",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "countryScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "country",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "postalCode",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "routingAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "routingAccountNumber",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "routingReferenceText",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "routingExplicitDetails",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"fields": [{"type": "STRING",
													 "name": "routingIdCodeScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "routingId",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "routingIds",
											 "mode": "REPEATED"},
											 {"type": "STRING",
											 "name": "routingName",
											 "mode": "REQUIRED"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "streetLine",
													 "mode": "REPEATED"}],
												 "type": "RECORD",
												 "name": "streetAddress",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "city",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "state",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "countryScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "country",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "postalCode",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "routingAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "routingAccountNumber",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "routingReferenceText",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "routingIdsAndExplicitDetails",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "beneficiaryBank",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"fields": [{"type": "STRING",
												 "name": "routingIdCodeScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "routingId",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "routingIds",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "routingName",
											 "mode": "REQUIRED"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "streetLine",
													 "mode": "REPEATED"}],
												 "type": "RECORD",
												 "name": "streetAddress",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "city",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "state",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "countryScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "country",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "postalCode",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "routingAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "routingAccountNumber",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "routingReferenceText",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "routingExplicitDetails",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"fields": [{"type": "STRING",
													 "name": "routingIdCodeScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "routingId",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "routingIds",
											 "mode": "REPEATED"},
											 {"type": "STRING",
											 "name": "routingName",
											 "mode": "REQUIRED"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "streetLine",
													 "mode": "REPEATED"}],
												 "type": "RECORD",
												 "name": "streetAddress",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "city",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "state",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "countryScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "country",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "postalCode",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "routingAddress",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "routingAccountNumber",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "routingReferenceText",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "routingIdsAndExplicitDetails",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "beneficiary",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "splitSettlement",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "settlementInstruction",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "settlementInformation",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_FxOptionPayout_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Currency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "currency",
						 "mode": "REQUIRED"},
						 {"type": "FLOAT",
						 "name": "amount",
						 "mode": "REQUIRED"},
						 {"type": "INTEGER",
						 "name": "calculationPeriodNumberOfDays",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "valueDate",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_FutureValueAmount_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "paymentAmount",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "unadjustedDate",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "dateAdjustments",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "adjustableDate",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDateAdjustments",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "relativeDate",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "paymentDate",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_SimplePayment_value",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "premium",
		 "mode": "NULLABLE"},
		 {"fields": [{"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "unadjustedDate",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "dateAdjustments",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "adjustableDate",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDateAdjustments",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "relativeDate",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "commencementDate",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "unadjustedDate",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "dateAdjustments",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "adjustableDate",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDateAdjustments",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "relativeDate",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "expirationDate",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "unadjustedDate",
						 "mode": "REPEATED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "dateAdjustments",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "adjustableDates",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "relativeDates",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "relevantUnderlyingDate",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "hourMinuteTime",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "businessCenterScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCenter",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "earliestExerciseTime",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "hourMinuteTime",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "businessCenterScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCenter",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "latestExerciseTime",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "hourMinuteTime",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "businessCenterScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCenter",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "expirationTime",
				 "mode": "REQUIRED"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "notionalReference",
					 "mode": "REPEATED"},
					 {"type": "FLOAT",
					 "name": "integralMultipleAmount",
					 "mode": "NULLABLE"},
					 {"type": "FLOAT",
					 "name": "minimumNotionalAmount",
					 "mode": "NULLABLE"},
					 {"type": "INTEGER",
					 "name": "minimumNumberOfOptions",
					 "mode": "NULLABLE"},
					 {"type": "FLOAT",
					 "name": "maximumNotionalAmount",
					 "mode": "NULLABLE"},
					 {"type": "FLOAT",
					 "name": "maximumNumberOfOptions",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "multipleExercise",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "payerPartyReference",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "payerAccountReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "receiverPartyReference",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "receiverAccountReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "notionalReference",
					 "mode": "REQUIRED"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "stepDate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "stepValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "currencyScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Currency_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "currencyScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "currency",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AmountSchedule_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "stepDate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "stepValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Schedule_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "feeAmountSchedule",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "stepDate",
							 "mode": "REQUIRED"},
							 {"type": "FLOAT",
							 "name": "stepValue",
							 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Schedule_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "stepDate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "stepValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"},
							 {"fields": [{"type": "STRING",
								 "name": "spreadScheduleTypeScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "type",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_SpreadSchedule_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "stepDate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "stepValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "currencyScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Currency_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "currencyScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "currency",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AmountSchedule_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "stepDate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "stepValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "buyer",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "seller",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_StrikeSchedule_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "feeRateSchedule",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDateAdjustments",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "feePaymentDate",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "exerciseFeeSchedule",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_AmericanExercise_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_Exercise_value",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "americanExercise",
		 "mode": "NULLABLE"},
		 {"fields": [{"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "unadjustedDate",
						 "mode": "REPEATED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "dateAdjustments",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "adjustableDates",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "relativeDates",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "bermudaExerciseDates",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "unadjustedDate",
						 "mode": "REPEATED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "dateAdjustments",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "adjustableDates",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "relativeDates",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "relevantUnderlyingDate",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "hourMinuteTime",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "businessCenterScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCenter",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "earliestExerciseTime",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "hourMinuteTime",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "businessCenterScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCenter",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "latestExerciseTime",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "hourMinuteTime",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "businessCenterScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCenter",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "expirationTime",
				 "mode": "REQUIRED"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "notionalReference",
					 "mode": "REPEATED"},
					 {"type": "FLOAT",
					 "name": "integralMultipleAmount",
					 "mode": "NULLABLE"},
					 {"type": "FLOAT",
					 "name": "minimumNotionalAmount",
					 "mode": "NULLABLE"},
					 {"type": "INTEGER",
					 "name": "minimumNumberOfOptions",
					 "mode": "NULLABLE"},
					 {"type": "FLOAT",
					 "name": "maximumNotionalAmount",
					 "mode": "NULLABLE"},
					 {"type": "FLOAT",
					 "name": "maximumNumberOfOptions",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "multipleExercise",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "payerPartyReference",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "payerAccountReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "receiverPartyReference",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "receiverAccountReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "notionalReference",
					 "mode": "REQUIRED"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "stepDate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "stepValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "currencyScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Currency_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "currencyScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "currency",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AmountSchedule_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "stepDate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "stepValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Schedule_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "feeAmountSchedule",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "stepDate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "stepValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Schedule_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "stepDate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "stepValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"},
							 {"fields": [{"type": "STRING",
								 "name": "spreadScheduleTypeScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "type",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_SpreadSchedule_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "stepDate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "stepValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "currencyScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Currency_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "currencyScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "currency",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AmountSchedule_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "initialValue",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "stepDate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "stepValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "step",
							 "mode": "REPEATED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "buyer",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "seller",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_StrikeSchedule_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "feeRateSchedule",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDateAdjustments",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "feePaymentDate",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "exerciseFeeSchedule",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_BermudaExercise_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_Exercise_value",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "bermudaExercise",
		 "mode": "NULLABLE"},
		 {"fields": [{"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "unadjustedDate",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "dateAdjustments",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "adjustableDate",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDateAdjustments",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "relativeDate",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "expirationDate",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "unadjustedDate",
						 "mode": "REPEATED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "dateAdjustments",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "adjustableDates",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "relativeDates",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "relevantUnderlyingDate",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "hourMinuteTime",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "businessCenterScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCenter",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "earliestExerciseTime",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "hourMinuteTime",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "businessCenterScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCenter",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "expirationTime",
				 "mode": "REQUIRED"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "notionalReference",
					 "mode": "REPEATED"},
					 {"type": "FLOAT",
					 "name": "integralMultipleAmount",
					 "mode": "NULLABLE"},
					 {"type": "FLOAT",
					 "name": "minimumNotionalAmount",
					 "mode": "NULLABLE"},
					 {"type": "INTEGER",
					 "name": "minimumNumberOfOptions",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "partialExercise",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "payerPartyReference",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "payerAccountReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "receiverPartyReference",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "receiverAccountReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "notionalReference",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "feeAmount",
					 "mode": "NULLABLE"},
					 {"type": "FLOAT",
					 "name": "feeRate",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDateAdjustments",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "feePaymentDate",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "exerciseFee",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_EuropeanExercise_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_Exercise_value",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "europeanExercise",
		 "mode": "NULLABLE"},
		 {"fields": [{"fields": [{"fields": [{"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "partyReference",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "exerciseNoticePartyReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "businessCenterScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCenter",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "exerciseNotice",
				 "mode": "NULLABLE"},
				 {"type": "BOOLEAN",
				 "name": "fallbackExercise",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "manualExercise",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "FLOAT",
				 "name": "thresholdRate",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "automaticExercise",
			 "mode": "NULLABLE"},
			 {"type": "BOOLEAN",
			 "name": "followUpConfirmation",
			 "mode": "REQUIRED"},
			 {"type": "BOOLEAN",
			 "name": "limitedRightToConfirm",
			 "mode": "NULLABLE"},
			 {"type": "BOOLEAN",
			 "name": "splitTicket",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "exerciseProcedure",
		 "mode": "REQUIRED"},
		 {"fields": [{"fields": [{"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "referenceCurrency",
				 "mode": "REQUIRED"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "determinationMethodScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "determinationMethod",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDateAdjustments",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "relativeDate",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"fields": [{"fields": [{"type": "STRING",
												 "name": "informationProviderScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "rateSource",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "rateSourcePageScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "rateSourcePage",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "rateSourcePageHeading",
											 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_InformationSource_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "informationProviderScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "rateSource",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "rateSourcePageScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "rateSourcePage",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "rateSourcePageHeading",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "hourMinuteTime",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "businessCenterScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCenter",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "fixingTime",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_FxInformationSource_value",
									 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "primaryRateSource",
							 "mode": "REQUIRED"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "informationProviderScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "rateSource",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "rateSourcePageScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "rateSourcePage",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "rateSourcePageHeading",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_InformationSource_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "informationProviderScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "rateSource",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "rateSourcePageScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "rateSourcePage",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "rateSourcePageHeading",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "hourMinuteTime",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "fixingTime",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_FxInformationSource_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "secondaryRateSource",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "hourMinuteTime",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "fixingTime",
							 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "fxSpotRateSource",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "composite",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"fields": [{"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_Currency_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "currency1",
								 "mode": "REQUIRED"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_Currency_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "currency2",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "quoteBasis",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_QuotedCurrencyPair_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_Currency_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "currency1",
								 "mode": "REQUIRED"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_Currency_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "currency2",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "quoteBasis",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "rate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "spotRate",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_FxFlexibleForwardRate_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_Currency_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "currency1",
								 "mode": "REQUIRED"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_Currency_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "currencyScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "currency2",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "quoteBasis",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "rate",
								 "mode": "REQUIRED"},
								 {"type": "FLOAT",
								 "name": "spotRate",
								 "mode": "NULLABLE"},
								 {"type": "FLOAT",
								 "name": "forwardPoints",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_CrossRate_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "quotedCurrencyPair",
						 "mode": "REQUIRED"},
						 {"type": "FLOAT",
						 "name": "rate",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "fxRate",
					 "mode": "REPEATED"},
					 {"fields": [{"fields": [{"fields": [{"fields": [{"type": "STRING",
									 "name": "informationProviderScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSource",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "rateSourcePageScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSourcePage",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "rateSourcePageHeading",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_InformationSource_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "informationProviderScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSource",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "rateSourcePageScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSourcePage",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "rateSourcePageHeading",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "hourMinuteTime",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "fixingTime",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_FxInformationSource_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "primaryRateSource",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"fields": [{"type": "STRING",
									 "name": "informationProviderScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSource",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "rateSourcePageScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSourcePage",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "rateSourcePageHeading",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_InformationSource_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "informationProviderScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSource",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "rateSourcePageScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSourcePage",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "rateSourcePageHeading",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "hourMinuteTime",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "fixingTime",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_FxInformationSource_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "secondaryRateSource",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "hourMinuteTime",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "fixingTime",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "fxSpotRateSource",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "quanto",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "determinationMethodScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "determinationMethod",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Offset_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Period_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodSkip",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_DateRange_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "unadjustedFirstDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "unadjustedLastDate",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_BusinessDateRange_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "scheduleBounds",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_RelativeDates_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "periodMultiplier",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "period",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "dayType",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "dateRelativeTo",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDateAdjustments",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "relativeDate",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"fields": [{"fields": [{"type": "STRING",
									 "name": "informationProviderScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSource",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "rateSourcePageScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSourcePage",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "rateSourcePageHeading",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_InformationSource_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "informationProviderScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSource",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "rateSourcePageScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSourcePage",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "rateSourcePageHeading",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "hourMinuteTime",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "fixingTime",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_FxInformationSource_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "primaryRateSource",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"fields": [{"type": "STRING",
									 "name": "informationProviderScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSource",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "rateSourcePageScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSourcePage",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "rateSourcePageHeading",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_InformationSource_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "informationProviderScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSource",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "rateSourcePageScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "rateSourcePage",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "rateSourcePageHeading",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "hourMinuteTime",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "fixingTime",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_FxInformationSource_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "secondaryRateSource",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "hourMinuteTime",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "fixingTime",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "fxSpotRateSource",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "crossCurrency",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "fxFeature",
			 "mode": "NULLABLE"},
			 {"fields": [{"fields": [{"fields": [{"fields": [{"type": "FLOAT",
							 "name": "strikePrice",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "strikePercentage",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "currencyScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Currency_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "currencyScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "currency",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_OptionStrike_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "FLOAT",
							 "name": "strikePrice",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "strikePercentage",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_OptionNumericStrike_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "upperStrike",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "upperStrikeNumberOfOptions",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "strikeSpread",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "unadjustedDate",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "dateAdjustments",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "adjustedDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "adjustableDate",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Offset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Period_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodSkip",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "unadjustedFirstDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "unadjustedLastDate",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_DateRange_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "unadjustedFirstDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "unadjustedLastDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "businessDayConvention",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "href",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCentersReference",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "businessCenterScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCenter",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "businessCenters",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_BusinessDateRange_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "scheduleBounds",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_RelativeDates_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "relativeDateAdjustments",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "relativeDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "expirationDateTwo",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "calendarSpread",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "strategyFeature",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "averagingInOut",
				 "mode": "REQUIRED"},
				 {"type": "FLOAT",
				 "name": "strikeFactor",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "startDate",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "endDate",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "rollConvention",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_CalculationPeriodFrequency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Frequency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "averagingPeriodFrequency",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "schedule",
					 "mode": "REPEATED"},
					 {"fields": [{"type": "INTEGER",
						 "name": "dateTime",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "averagingDateTimes",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "INTEGER",
							 "name": "dateTime",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "observationNumber",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "weight",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "averagingObservation",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "averagingObservations",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "marketDisruptionScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "marketDisruption",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "averagingPeriodIn",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "startDate",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "endDate",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "rollConvention",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_CalculationPeriodFrequency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Frequency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "averagingPeriodFrequency",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "schedule",
					 "mode": "REPEATED"},
					 {"fields": [{"type": "INTEGER",
						 "name": "dateTime",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "averagingDateTimes",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "INTEGER",
							 "name": "dateTime",
							 "mode": "NULLABLE"},
							 {"type": "INTEGER",
							 "name": "observationNumber",
							 "mode": "NULLABLE"},
							 {"type": "FLOAT",
							 "name": "weight",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "averagingObservation",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "averagingObservations",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "marketDisruptionScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "marketDisruption",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "averagingPeriodOut",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "asian",
			 "mode": "NULLABLE"},
			 {"fields": [{"fields": [{"fields": [{"type": "STRING",
						 "name": "startDate",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "endDate",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "rollConvention",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_CalculationPeriodFrequency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Frequency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "averagingPeriodFrequency",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "schedule",
					 "mode": "REPEATED"},
					 {"fields": [{"type": "STRING",
						 "name": "date",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "triggerDates",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "FLOAT",
						 "name": "level",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "levelPercentage",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "bankruptcy",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "BOOLEAN",
								 "name": "applicable",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "BOOLEAN",
									 "name": "applicable",
									 "mode": "REQUIRED"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Offset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Period_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodSkip",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "unadjustedFirstDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "unadjustedLastDate",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_DateRange_value",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "unadjustedFirstDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "unadjustedLastDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "businessDayConvention",
													 "mode": "REQUIRED"},
													 {"fields": [{"type": "STRING",
														 "name": "href",
														 "mode": "REQUIRED"},
														 {"type": "STRING",
														 "name": "keyValue",
														 "mode": "REQUIRED"}],
													 "type": "RECORD",
													 "name": "businessCentersReference",
													 "mode": "NULLABLE"},
													 {"fields": [{"type": "STRING",
														 "name": "id",
														 "mode": "NULLABLE"},
														 {"fields": [{"type": "STRING",
															 "name": "businessCenterScheme",
															 "mode": "NULLABLE"},
															 {"type": "STRING",
															 "name": "id",
															 "mode": "NULLABLE"},
															 {"type": "STRING",
															 "name": "keyValue",
															 "mode": "REQUIRED"}],
														 "type": "RECORD",
														 "name": "businessCenter",
														 "mode": "REPEATED"}],
													 "type": "RECORD",
													 "name": "businessCenters",
													 "mode": "NULLABLE"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_BusinessDateRange_value",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "scheduleBounds",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_RelativeDates_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "businessDayConvention",
												 "mode": "REQUIRED"},
												 {"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCentersReference",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"fields": [{"type": "STRING",
														 "name": "businessCenterScheme",
														 "mode": "NULLABLE"},
														 {"type": "STRING",
														 "name": "id",
														 "mode": "NULLABLE"},
														 {"type": "STRING",
														 "name": "keyValue",
														 "mode": "REQUIRED"}],
													 "type": "RECORD",
													 "name": "businessCenter",
													 "mode": "REPEATED"}],
												 "type": "RECORD",
												 "name": "businessCenters",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "relativeDateAdjustments",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "paymentDatesReference",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "dateRelativeToPaymentDates",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "calculationPeriodDatesReference",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "dateRelativeToCalculationPeriodDates",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_FxFixingDate_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_DateOffset_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "gracePeriod",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "gracePeriodExtension",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_Money_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "spreadConversionFactor",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "quantityUnitScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "spreadUnit",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_CommoditySpread_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "stepDate",
											 "mode": "REQUIRED"},
											 {"type": "FLOAT",
											 "name": "stepValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "step",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_CalculationAmount_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "paymentRequirement",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "failureToPay",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "failureToPayPrincipal",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "failureToPayInterest",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "obligationDefault",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "obligationAcceleration",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "repudiationMoratorium",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "BOOLEAN",
								 "name": "applicable",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "restructuringScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "restructuringType",
								 "mode": "NULLABLE"},
								 {"type": "BOOLEAN",
								 "name": "multipleHolderObligation",
								 "mode": "NULLABLE"},
								 {"type": "BOOLEAN",
								 "name": "multipleCreditEventNotices",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "restructuring",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "distressedRatingsDowngrade",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "maturityExtension",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "writedown",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "impliedWritedown",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Money_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "spreadConversionFactor",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "quantityUnitScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "spreadUnit",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_CommoditySpread_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "stepDate",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "stepValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "step",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_CalculationAmount_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "defaultRequirement",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "buyerPartyReference",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "sellerPartyReference",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "notifyingParty",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "BOOLEAN",
									 "name": "standardPublicSources",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "publicSource",
									 "mode": "REPEATED"},
									 {"type": "INTEGER",
									 "name": "specifiedNumber",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "publiclyAvailableInformation",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "creditEventNotice",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "creditEvents",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "creditEventsReference",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "triggerType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "triggerTimeType",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "trigger",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "payerPartyReference",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "payerAccountReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "receiverPartyReference",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "receiverAccountReference",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "levelPercentage",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "amount",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "time",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Currency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "currency",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "unadjustedDate",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "dateAdjustments",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "adjustableDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Offset_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Period_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodSkip",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "unadjustedFirstDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "unadjustedLastDate",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_DateRange_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "unadjustedFirstDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "unadjustedLastDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_BusinessDateRange_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "scheduleBounds",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_RelativeDates_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "businessDayConvention",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "href",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCentersReference",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "businessCenterScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCenter",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "businessCenters",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "relativeDateAdjustments",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "featurePaymentDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "featurePayment",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "barrierCap",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "startDate",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "endDate",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "rollConvention",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_CalculationPeriodFrequency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Frequency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "averagingPeriodFrequency",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "schedule",
					 "mode": "REPEATED"},
					 {"fields": [{"type": "STRING",
						 "name": "date",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "triggerDates",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "FLOAT",
						 "name": "level",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "levelPercentage",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "bankruptcy",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "BOOLEAN",
								 "name": "applicable",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "BOOLEAN",
									 "name": "applicable",
									 "mode": "REQUIRED"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Offset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Period_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodSkip",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "unadjustedFirstDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "unadjustedLastDate",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_DateRange_value",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "unadjustedFirstDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "unadjustedLastDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "businessDayConvention",
													 "mode": "REQUIRED"},
													 {"fields": [{"type": "STRING",
														 "name": "href",
														 "mode": "REQUIRED"},
														 {"type": "STRING",
														 "name": "keyValue",
														 "mode": "REQUIRED"}],
													 "type": "RECORD",
													 "name": "businessCentersReference",
													 "mode": "NULLABLE"},
													 {"fields": [{"type": "STRING",
														 "name": "id",
														 "mode": "NULLABLE"},
														 {"fields": [{"type": "STRING",
															 "name": "businessCenterScheme",
															 "mode": "NULLABLE"},
															 {"type": "STRING",
															 "name": "id",
															 "mode": "NULLABLE"},
															 {"type": "STRING",
															 "name": "keyValue",
															 "mode": "REQUIRED"}],
														 "type": "RECORD",
														 "name": "businessCenter",
														 "mode": "REPEATED"}],
													 "type": "RECORD",
													 "name": "businessCenters",
													 "mode": "NULLABLE"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_BusinessDateRange_value",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "scheduleBounds",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_RelativeDates_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "businessDayConvention",
												 "mode": "REQUIRED"},
												 {"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCentersReference",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"fields": [{"type": "STRING",
														 "name": "businessCenterScheme",
														 "mode": "NULLABLE"},
														 {"type": "STRING",
														 "name": "id",
														 "mode": "NULLABLE"},
														 {"type": "STRING",
														 "name": "keyValue",
														 "mode": "REQUIRED"}],
													 "type": "RECORD",
													 "name": "businessCenter",
													 "mode": "REPEATED"}],
												 "type": "RECORD",
												 "name": "businessCenters",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "relativeDateAdjustments",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "paymentDatesReference",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "dateRelativeToPaymentDates",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "calculationPeriodDatesReference",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "dateRelativeToCalculationPeriodDates",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_FxFixingDate_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_DateOffset_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "gracePeriod",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "gracePeriodExtension",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_Money_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "spreadConversionFactor",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "quantityUnitScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "spreadUnit",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_CommoditySpread_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "stepDate",
											 "mode": "REQUIRED"},
											 {"type": "FLOAT",
											 "name": "stepValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "step",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_CalculationAmount_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "paymentRequirement",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "failureToPay",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "failureToPayPrincipal",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "failureToPayInterest",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "obligationDefault",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "obligationAcceleration",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "repudiationMoratorium",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "BOOLEAN",
								 "name": "applicable",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "restructuringScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "restructuringType",
								 "mode": "NULLABLE"},
								 {"type": "BOOLEAN",
								 "name": "multipleHolderObligation",
								 "mode": "NULLABLE"},
								 {"type": "BOOLEAN",
								 "name": "multipleCreditEventNotices",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "restructuring",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "distressedRatingsDowngrade",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "maturityExtension",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "writedown",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "impliedWritedown",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Money_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "spreadConversionFactor",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "quantityUnitScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "spreadUnit",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_CommoditySpread_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "stepDate",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "stepValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "step",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_CalculationAmount_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "defaultRequirement",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "buyerPartyReference",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "sellerPartyReference",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "notifyingParty",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "BOOLEAN",
									 "name": "standardPublicSources",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "publicSource",
									 "mode": "REPEATED"},
									 {"type": "INTEGER",
									 "name": "specifiedNumber",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "publiclyAvailableInformation",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "creditEventNotice",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "creditEvents",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "creditEventsReference",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "triggerType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "triggerTimeType",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "trigger",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "payerPartyReference",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "payerAccountReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "receiverPartyReference",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "receiverAccountReference",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "levelPercentage",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "amount",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "time",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Currency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "currency",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "unadjustedDate",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "dateAdjustments",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "adjustableDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Offset_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Period_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodSkip",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "unadjustedFirstDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "unadjustedLastDate",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_DateRange_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "unadjustedFirstDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "unadjustedLastDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_BusinessDateRange_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "scheduleBounds",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_RelativeDates_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "businessDayConvention",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "href",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCentersReference",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "businessCenterScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCenter",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "businessCenters",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "relativeDateAdjustments",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "featurePaymentDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "featurePayment",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "barrierFloor",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "barrier",
			 "mode": "NULLABLE"},
			 {"fields": [{"fields": [{"fields": [{"type": "STRING",
						 "name": "startDate",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "endDate",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "rollConvention",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_CalculationPeriodFrequency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Frequency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "averagingPeriodFrequency",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "schedule",
					 "mode": "REPEATED"},
					 {"fields": [{"type": "STRING",
						 "name": "date",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "triggerDates",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "FLOAT",
						 "name": "level",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "levelPercentage",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "bankruptcy",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "BOOLEAN",
								 "name": "applicable",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "BOOLEAN",
									 "name": "applicable",
									 "mode": "REQUIRED"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Offset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Period_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodSkip",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "unadjustedFirstDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "unadjustedLastDate",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_DateRange_value",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "unadjustedFirstDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "unadjustedLastDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "businessDayConvention",
													 "mode": "REQUIRED"},
													 {"fields": [{"type": "STRING",
														 "name": "href",
														 "mode": "REQUIRED"},
														 {"type": "STRING",
														 "name": "keyValue",
														 "mode": "REQUIRED"}],
													 "type": "RECORD",
													 "name": "businessCentersReference",
													 "mode": "NULLABLE"},
													 {"fields": [{"type": "STRING",
														 "name": "id",
														 "mode": "NULLABLE"},
														 {"fields": [{"type": "STRING",
															 "name": "businessCenterScheme",
															 "mode": "NULLABLE"},
															 {"type": "STRING",
															 "name": "id",
															 "mode": "NULLABLE"},
															 {"type": "STRING",
															 "name": "keyValue",
															 "mode": "REQUIRED"}],
														 "type": "RECORD",
														 "name": "businessCenter",
														 "mode": "REPEATED"}],
													 "type": "RECORD",
													 "name": "businessCenters",
													 "mode": "NULLABLE"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_BusinessDateRange_value",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "scheduleBounds",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_RelativeDates_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "businessDayConvention",
												 "mode": "REQUIRED"},
												 {"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCentersReference",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"fields": [{"type": "STRING",
														 "name": "businessCenterScheme",
														 "mode": "NULLABLE"},
														 {"type": "STRING",
														 "name": "id",
														 "mode": "NULLABLE"},
														 {"type": "STRING",
														 "name": "keyValue",
														 "mode": "REQUIRED"}],
													 "type": "RECORD",
													 "name": "businessCenter",
													 "mode": "REPEATED"}],
												 "type": "RECORD",
												 "name": "businessCenters",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "relativeDateAdjustments",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "paymentDatesReference",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "dateRelativeToPaymentDates",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "calculationPeriodDatesReference",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "dateRelativeToCalculationPeriodDates",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_FxFixingDate_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_DateOffset_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "gracePeriod",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "gracePeriodExtension",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_Money_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "spreadConversionFactor",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "quantityUnitScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "spreadUnit",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_CommoditySpread_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "stepDate",
											 "mode": "REQUIRED"},
											 {"type": "FLOAT",
											 "name": "stepValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "step",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_CalculationAmount_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "paymentRequirement",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "failureToPay",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "failureToPayPrincipal",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "failureToPayInterest",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "obligationDefault",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "obligationAcceleration",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "repudiationMoratorium",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "BOOLEAN",
								 "name": "applicable",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "restructuringScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "restructuringType",
								 "mode": "NULLABLE"},
								 {"type": "BOOLEAN",
								 "name": "multipleHolderObligation",
								 "mode": "NULLABLE"},
								 {"type": "BOOLEAN",
								 "name": "multipleCreditEventNotices",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "restructuring",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "distressedRatingsDowngrade",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "maturityExtension",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "writedown",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "impliedWritedown",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Money_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "spreadConversionFactor",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "quantityUnitScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "spreadUnit",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_CommoditySpread_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "stepDate",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "stepValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "step",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_CalculationAmount_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "defaultRequirement",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "buyerPartyReference",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "sellerPartyReference",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "notifyingParty",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "BOOLEAN",
									 "name": "standardPublicSources",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "publicSource",
									 "mode": "REPEATED"},
									 {"type": "INTEGER",
									 "name": "specifiedNumber",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "publiclyAvailableInformation",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "creditEventNotice",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "creditEvents",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "creditEventsReference",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "triggerType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "triggerTimeType",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "trigger",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "payerPartyReference",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "payerAccountReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "receiverPartyReference",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "receiverAccountReference",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "levelPercentage",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "amount",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "time",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Currency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "currency",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "unadjustedDate",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "dateAdjustments",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "adjustableDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Offset_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Period_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodSkip",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "unadjustedFirstDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "unadjustedLastDate",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_DateRange_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "unadjustedFirstDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "unadjustedLastDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_BusinessDateRange_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "scheduleBounds",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_RelativeDates_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "businessDayConvention",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "href",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCentersReference",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "businessCenterScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCenter",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "businessCenters",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "relativeDateAdjustments",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "featurePaymentDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "featurePayment",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "knockIn",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "startDate",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "endDate",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "rollConvention",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_CalculationPeriodFrequency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Frequency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "averagingPeriodFrequency",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "schedule",
					 "mode": "REPEATED"},
					 {"fields": [{"type": "STRING",
						 "name": "date",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "triggerDates",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "FLOAT",
						 "name": "level",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "levelPercentage",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "bankruptcy",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "BOOLEAN",
								 "name": "applicable",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "BOOLEAN",
									 "name": "applicable",
									 "mode": "REQUIRED"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Offset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Period_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodSkip",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "unadjustedFirstDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "unadjustedLastDate",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_DateRange_value",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "unadjustedFirstDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "unadjustedLastDate",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "businessDayConvention",
													 "mode": "REQUIRED"},
													 {"fields": [{"type": "STRING",
														 "name": "href",
														 "mode": "REQUIRED"},
														 {"type": "STRING",
														 "name": "keyValue",
														 "mode": "REQUIRED"}],
													 "type": "RECORD",
													 "name": "businessCentersReference",
													 "mode": "NULLABLE"},
													 {"fields": [{"type": "STRING",
														 "name": "id",
														 "mode": "NULLABLE"},
														 {"fields": [{"type": "STRING",
															 "name": "businessCenterScheme",
															 "mode": "NULLABLE"},
															 {"type": "STRING",
															 "name": "id",
															 "mode": "NULLABLE"},
															 {"type": "STRING",
															 "name": "keyValue",
															 "mode": "REQUIRED"}],
														 "type": "RECORD",
														 "name": "businessCenter",
														 "mode": "REPEATED"}],
													 "type": "RECORD",
													 "name": "businessCenters",
													 "mode": "NULLABLE"}],
												 "type": "RECORD",
												 "name": "org_fpml_fpml_5_BusinessDateRange_value",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "scheduleBounds",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_RelativeDates_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "dateRelativeTo",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "adjustedDate",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "businessDayConvention",
												 "mode": "REQUIRED"},
												 {"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCentersReference",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"fields": [{"type": "STRING",
														 "name": "businessCenterScheme",
														 "mode": "NULLABLE"},
														 {"type": "STRING",
														 "name": "id",
														 "mode": "NULLABLE"},
														 {"type": "STRING",
														 "name": "keyValue",
														 "mode": "REQUIRED"}],
													 "type": "RECORD",
													 "name": "businessCenter",
													 "mode": "REPEATED"}],
												 "type": "RECORD",
												 "name": "businessCenters",
												 "mode": "NULLABLE"}],
											 "type": "RECORD",
											 "name": "relativeDateAdjustments",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "paymentDatesReference",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "dateRelativeToPaymentDates",
											 "mode": "NULLABLE"},
											 {"fields": [{"fields": [{"type": "STRING",
													 "name": "href",
													 "mode": "REQUIRED"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "calculationPeriodDatesReference",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "dateRelativeToCalculationPeriodDates",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_FxFixingDate_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "INTEGER",
											 "name": "periodMultiplier",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "period",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "dayType",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_DateOffset_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "gracePeriod",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "gracePeriodExtension",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_Money_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "spreadConversionFactor",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "quantityUnitScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "spreadUnit",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_CommoditySpread_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"fields": [{"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_Currency_value",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "currencyScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "currency",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "amount",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "stepDate",
											 "mode": "REQUIRED"},
											 {"type": "FLOAT",
											 "name": "stepValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "step",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_CalculationAmount_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "paymentRequirement",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "failureToPay",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "failureToPayPrincipal",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "failureToPayInterest",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "obligationDefault",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "obligationAcceleration",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "repudiationMoratorium",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "BOOLEAN",
								 "name": "applicable",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "restructuringScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "restructuringType",
								 "mode": "NULLABLE"},
								 {"type": "BOOLEAN",
								 "name": "multipleHolderObligation",
								 "mode": "NULLABLE"},
								 {"type": "BOOLEAN",
								 "name": "multipleCreditEventNotices",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "restructuring",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "distressedRatingsDowngrade",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "maturityExtension",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "writedown",
							 "mode": "NULLABLE"},
							 {"type": "BOOLEAN",
							 "name": "impliedWritedown",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Money_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "spreadConversionFactor",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "quantityUnitScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "spreadUnit",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_CommoditySpread_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_Currency_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "currencyScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "currency",
									 "mode": "REQUIRED"},
									 {"type": "FLOAT",
									 "name": "amount",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "stepDate",
										 "mode": "REQUIRED"},
										 {"type": "FLOAT",
										 "name": "stepValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "step",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_CalculationAmount_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "defaultRequirement",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "buyerPartyReference",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "sellerPartyReference",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "notifyingParty",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "BOOLEAN",
									 "name": "standardPublicSources",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "publicSource",
									 "mode": "REPEATED"},
									 {"type": "INTEGER",
									 "name": "specifiedNumber",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "publiclyAvailableInformation",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "creditEventNotice",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "creditEvents",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "creditEventsReference",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "triggerType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "triggerTimeType",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "trigger",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "payerPartyReference",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "payerAccountReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "receiverPartyReference",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "receiverAccountReference",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "levelPercentage",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "amount",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "time",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Currency_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "currencyScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "currency",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "unadjustedDate",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "dateAdjustments",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "adjustableDate",
							 "mode": "NULLABLE"},
							 {"fields": [{"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Offset_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_Period_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodSkip",
									 "mode": "NULLABLE"},
									 {"fields": [{"fields": [{"type": "STRING",
											 "name": "unadjustedFirstDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "unadjustedLastDate",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_DateRange_value",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "unadjustedFirstDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "unadjustedLastDate",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "businessDayConvention",
											 "mode": "REQUIRED"},
											 {"fields": [{"type": "STRING",
												 "name": "href",
												 "mode": "REQUIRED"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCentersReference",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"fields": [{"type": "STRING",
													 "name": "businessCenterScheme",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "id",
													 "mode": "NULLABLE"},
													 {"type": "STRING",
													 "name": "keyValue",
													 "mode": "REQUIRED"}],
												 "type": "RECORD",
												 "name": "businessCenter",
												 "mode": "REPEATED"}],
											 "type": "RECORD",
											 "name": "businessCenters",
											 "mode": "NULLABLE"}],
										 "type": "RECORD",
										 "name": "org_fpml_fpml_5_BusinessDateRange_value",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "scheduleBounds",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_RelativeDates_value",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "INTEGER",
									 "name": "periodMultiplier",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "period",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "dayType",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "dateRelativeTo",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "adjustedDate",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "businessDayConvention",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "href",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCentersReference",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "businessCenterScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCenter",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "businessCenters",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "relativeDateAdjustments",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "relativeDate",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "featurePaymentDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "featurePayment",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "knockOut",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "knock",
			 "mode": "NULLABLE"},
			 {"fields": [{"fields": [{"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "payerPartyReference",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "payerAccountReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "receiverPartyReference",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "receiverAccountReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "underlyerReference",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "passThroughPercentage",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "passThroughItem",
				 "mode": "REPEATED"}],
			 "type": "RECORD",
			 "name": "passThrough",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "feature",
		 "mode": "NULLABLE"},
		 {"fields": [{"type": "STRING",
			 "name": "href",
			 "mode": "REQUIRED"},
			 {"type": "STRING",
			 "name": "keyValue",
			 "mode": "REQUIRED"}],
		 "type": "RECORD",
		 "name": "notionalReference",
		 "mode": "NULLABLE"},
		 {"fields": [{"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "currency",
				 "mode": "REQUIRED"},
				 {"type": "FLOAT",
				 "name": "amount",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_Money_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "currency",
				 "mode": "REQUIRED"},
				 {"type": "FLOAT",
				 "name": "amount",
				 "mode": "REQUIRED"},
				 {"type": "FLOAT",
				 "name": "spreadConversionFactor",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "quantityUnitScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "spreadUnit",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_CommoditySpread_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "currency",
				 "mode": "REQUIRED"},
				 {"type": "FLOAT",
				 "name": "amount",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "stepDate",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "stepValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "step",
				 "mode": "REPEATED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_CalculationAmount_value",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "notionalAmount",
		 "mode": "NULLABLE"},
		 {"type": "FLOAT",
		 "name": "optionEntitlement",
		 "mode": "NULLABLE"},
		 {"fields": [{"fields": [{"type": "STRING",
				 "name": "currencyScheme",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_Currency_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "currencyScheme",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "entitlementCurrency",
		 "mode": "NULLABLE"},
		 {"type": "FLOAT",
		 "name": "numberOfOptions",
		 "mode": "NULLABLE"},
		 {"type": "STRING",
		 "name": "settlementType",
		 "mode": "NULLABLE"},
		 {"fields": [{"type": "STRING",
			 "name": "id",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "unadjustedDate",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "businessDayConvention",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCentersReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "businessCenterScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCenter",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "businessCenters",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "dateAdjustments",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "adjustedDate",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "adjustableDate",
			 "mode": "NULLABLE"},
			 {"fields": [{"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"type": "INTEGER",
					 "name": "periodMultiplier",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "period",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "dayType",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "businessDayConvention",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCentersReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "businessCenterScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCenter",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "businessCenters",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "dateRelativeTo",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "adjustedDate",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"type": "INTEGER",
					 "name": "periodMultiplier",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "period",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "dayType",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_Offset_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"type": "INTEGER",
					 "name": "periodMultiplier",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "period",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_Period_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"type": "INTEGER",
					 "name": "periodMultiplier",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "period",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "dayType",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "businessDayConvention",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCentersReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "businessCenterScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCenter",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "businessCenters",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "dateRelativeTo",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "adjustedDate",
					 "mode": "NULLABLE"},
					 {"type": "INTEGER",
					 "name": "periodSkip",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "unadjustedFirstDate",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "unadjustedLastDate",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_DateRange_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "unadjustedFirstDate",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "unadjustedLastDate",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_BusinessDateRange_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "scheduleBounds",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_RelativeDates_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"type": "INTEGER",
					 "name": "periodMultiplier",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "period",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "dayType",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "businessDayConvention",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "businessCentersReference",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "businessCenterScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCenter",
						 "mode": "REPEATED"}],
					 "type": "RECORD",
					 "name": "businessCenters",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "dateRelativeTo",
					 "mode": "REQUIRED"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "adjustedDate",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "relativeDateAdjustments",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "relativeDate",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "settlementDate",
		 "mode": "NULLABLE"},
		 {"fields": [{"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "currency",
				 "mode": "REQUIRED"},
				 {"type": "FLOAT",
				 "name": "amount",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_Money_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "currency",
				 "mode": "REQUIRED"},
				 {"type": "FLOAT",
				 "name": "amount",
				 "mode": "REQUIRED"},
				 {"type": "FLOAT",
				 "name": "spreadConversionFactor",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "quantityUnitScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "spreadUnit",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_CommoditySpread_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "currency",
				 "mode": "REQUIRED"},
				 {"type": "FLOAT",
				 "name": "amount",
				 "mode": "REQUIRED"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "stepDate",
					 "mode": "REQUIRED"},
					 {"type": "FLOAT",
					 "name": "stepValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "step",
				 "mode": "REPEATED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_CalculationAmount_value",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "settlementAmount",
		 "mode": "NULLABLE"},
		 {"fields": [{"fields": [{"type": "STRING",
				 "name": "currencyScheme",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_Currency_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "currencyScheme",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "keyValue",
				 "mode": "REQUIRED"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "settlementCurrency",
		 "mode": "NULLABLE"},
		 {"fields": [{"fields": [{"fields": [{"fields": [{"fields": [{"type": "STRING",
							 "name": "floatingRateIndexScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "floatingRateIndex",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Period_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Offset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodSkip",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "unadjustedFirstDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "unadjustedLastDate",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_DateRange_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "unadjustedFirstDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "unadjustedLastDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "businessDayConvention",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "href",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCentersReference",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "businessCenterScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCenter",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "businessCenters",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_BusinessDateRange_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "scheduleBounds",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_RelativeDates_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "relativeDateAdjustments",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "paymentDatesReference",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "dateRelativeToPaymentDates",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "calculationPeriodDatesReference",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "dateRelativeToCalculationPeriodDates",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_FxFixingDate_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_DateOffset_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "indexTenor",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "spread",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "side",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_SwapCurveValuation_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "floatingRateIndexScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "floatingRateIndex",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Period_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Offset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodSkip",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "unadjustedFirstDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "unadjustedLastDate",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_DateRange_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "unadjustedFirstDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "unadjustedLastDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "businessDayConvention",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "href",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCentersReference",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "businessCenterScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCenter",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "businessCenters",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_BusinessDateRange_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "scheduleBounds",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_RelativeDates_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "relativeDateAdjustments",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "paymentDatesReference",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "dateRelativeToPaymentDates",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "calculationPeriodDatesReference",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "dateRelativeToCalculationPeriodDates",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_FxFixingDate_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_DateOffset_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "indexTenor",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "spread",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "side",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "interpolationMethodScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "interpolationMethod",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "earlyCallDate",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_MakeWholeAmount_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "swapUnwindValue",
				 "mode": "REQUIRED"},
				 {"fields": [{"fields": [{"fields": [{"type": "STRING",
							 "name": "floatingRateIndexScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "floatingRateIndex",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Period_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Offset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodSkip",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "unadjustedFirstDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "unadjustedLastDate",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_DateRange_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "unadjustedFirstDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "unadjustedLastDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "businessDayConvention",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "href",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCentersReference",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "businessCenterScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCenter",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "businessCenters",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_BusinessDateRange_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "scheduleBounds",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_RelativeDates_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "relativeDateAdjustments",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "paymentDatesReference",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "dateRelativeToPaymentDates",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "calculationPeriodDatesReference",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "dateRelativeToCalculationPeriodDates",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_FxFixingDate_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_DateOffset_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "indexTenor",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "spread",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "side",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "interpolationMethodScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "interpolationMethod",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "earlyCallDate",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_MakeWholeAmount_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "floatingRateIndexScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "floatingRateIndex",
						 "mode": "REQUIRED"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Period_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_Offset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodSkip",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "unadjustedFirstDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "unadjustedLastDate",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_DateRange_value",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "unadjustedFirstDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "unadjustedLastDate",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "businessDayConvention",
										 "mode": "REQUIRED"},
										 {"fields": [{"type": "STRING",
											 "name": "href",
											 "mode": "REQUIRED"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCentersReference",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"fields": [{"type": "STRING",
												 "name": "businessCenterScheme",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "id",
												 "mode": "NULLABLE"},
												 {"type": "STRING",
												 "name": "keyValue",
												 "mode": "REQUIRED"}],
											 "type": "RECORD",
											 "name": "businessCenter",
											 "mode": "REPEATED"}],
										 "type": "RECORD",
										 "name": "businessCenters",
										 "mode": "NULLABLE"}],
									 "type": "RECORD",
									 "name": "org_fpml_fpml_5_BusinessDateRange_value",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "scheduleBounds",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_RelativeDates_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "dateRelativeTo",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "adjustedDate",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "businessDayConvention",
									 "mode": "REQUIRED"},
									 {"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCentersReference",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"fields": [{"type": "STRING",
											 "name": "businessCenterScheme",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "id",
											 "mode": "NULLABLE"},
											 {"type": "STRING",
											 "name": "keyValue",
											 "mode": "REQUIRED"}],
										 "type": "RECORD",
										 "name": "businessCenter",
										 "mode": "REPEATED"}],
									 "type": "RECORD",
									 "name": "businessCenters",
									 "mode": "NULLABLE"}],
								 "type": "RECORD",
								 "name": "relativeDateAdjustments",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "paymentDatesReference",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "dateRelativeToPaymentDates",
								 "mode": "NULLABLE"},
								 {"fields": [{"fields": [{"type": "STRING",
										 "name": "href",
										 "mode": "REQUIRED"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "calculationPeriodDatesReference",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "dateRelativeToCalculationPeriodDates",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_FxFixingDate_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "INTEGER",
								 "name": "periodMultiplier",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "period",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "dayType",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_DateOffset_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "indexTenor",
						 "mode": "NULLABLE"},
						 {"type": "FLOAT",
						 "name": "spread",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "side",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_SwapCurveValuation_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "makeWholeAmount",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "referenceSwapCurve",
			 "mode": "NULLABLE"},
			 {"fields": [{"fields": [{"type": "FLOAT",
					 "name": "strikePrice",
					 "mode": "NULLABLE"},
					 {"type": "FLOAT",
					 "name": "strikePercentage",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_OptionStrike_value",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "FLOAT",
					 "name": "strikePrice",
					 "mode": "NULLABLE"},
					 {"type": "FLOAT",
					 "name": "strikePercentage",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "org_fpml_fpml_5_OptionNumericStrike_value",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "price",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "strike",
		 "mode": "REQUIRED"},
		 {"fields": [{"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "instrumentIdScheme",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "instrumentId",
				 "mode": "REPEATED"},
				 {"type": "STRING",
				 "name": "description",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "currency",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "exchangeIdScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "exchangeId",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "clearanceSystemScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "clearanceSystem",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "definition",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "issuerName",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "issuerPartyReference",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "creditSeniorityScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "seniority",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "couponTypeScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "couponType",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "couponRate",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "maturity",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "parValue",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "faceAmount",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Period_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Offset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodSkip",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "unadjustedFirstDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "unadjustedLastDate",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_DateRange_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "unadjustedFirstDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "unadjustedLastDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_BusinessDateRange_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "scheduleBounds",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_RelativeDates_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "relativeDateAdjustments",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "paymentDatesReference",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "dateRelativeToPaymentDates",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "calculationPeriodDatesReference",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "dateRelativeToCalculationPeriodDates",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_FxFixingDate_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_DateOffset_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "paymentFrequency",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "dayCountFractionScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "dayCountFraction",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_Bond_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "instrumentIdScheme",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "instrumentId",
				 "mode": "REPEATED"},
				 {"type": "STRING",
				 "name": "description",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "currency",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "exchangeIdScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "exchangeId",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "clearanceSystemScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "clearanceSystem",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "definition",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "issuerName",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "issuerPartyReference",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "creditSeniorityScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "seniority",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "couponTypeScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "couponType",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "couponRate",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "maturity",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "parValue",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "faceAmount",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Period_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Offset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodSkip",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "unadjustedFirstDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "unadjustedLastDate",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_DateRange_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "unadjustedFirstDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "unadjustedLastDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_BusinessDateRange_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "scheduleBounds",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_RelativeDates_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "relativeDateAdjustments",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "paymentDatesReference",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "dateRelativeToPaymentDates",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "calculationPeriodDatesReference",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "dateRelativeToCalculationPeriodDates",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_FxFixingDate_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_DateOffset_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "paymentFrequency",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "dayCountFractionScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "dayCountFraction",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "instrumentIdScheme",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "instrumentId",
					 "mode": "REPEATED"},
					 {"type": "STRING",
					 "name": "description",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "exchangeIdScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "exchangeId",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "clearanceSystemScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "clearanceSystem",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "definition",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "exchangeIdScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "relatedExchangeId",
					 "mode": "REPEATED"},
					 {"fields": [{"type": "STRING",
						 "name": "exchangeIdScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "optionsExchangeId",
					 "mode": "REPEATED"},
					 {"fields": [{"type": "STRING",
						 "name": "exchangeIdScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "specifiedExchangeId",
					 "mode": "REPEATED"}],
				 "type": "RECORD",
				 "name": "underlyingEquity",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "redemptionDate",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_ConvertibleBond_value",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "bond",
		 "mode": "NULLABLE"},
		 {"fields": [{"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "instrumentIdScheme",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "instrumentId",
				 "mode": "REPEATED"},
				 {"type": "STRING",
				 "name": "description",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "currency",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "exchangeIdScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "exchangeId",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "clearanceSystemScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "clearanceSystem",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "definition",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "issuerName",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "issuerPartyReference",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "creditSeniorityScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "seniority",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "couponTypeScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "couponType",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "couponRate",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "maturity",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "parValue",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "faceAmount",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Period_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Offset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodSkip",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "unadjustedFirstDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "unadjustedLastDate",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_DateRange_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "unadjustedFirstDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "unadjustedLastDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_BusinessDateRange_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "scheduleBounds",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_RelativeDates_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "relativeDateAdjustments",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "paymentDatesReference",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "dateRelativeToPaymentDates",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "calculationPeriodDatesReference",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "dateRelativeToCalculationPeriodDates",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_FxFixingDate_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_DateOffset_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "paymentFrequency",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "dayCountFractionScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "dayCountFraction",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "id",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "instrumentIdScheme",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "instrumentId",
					 "mode": "REPEATED"},
					 {"type": "STRING",
					 "name": "description",
					 "mode": "NULLABLE"},
					 {"fields": [{"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "currencyScheme",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "org_fpml_fpml_5_Currency_value",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "currency",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "exchangeIdScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "exchangeId",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "clearanceSystemScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "clearanceSystem",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "href",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "definition",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "exchangeIdScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "relatedExchangeId",
					 "mode": "REPEATED"},
					 {"fields": [{"type": "STRING",
						 "name": "exchangeIdScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "optionsExchangeId",
					 "mode": "REPEATED"},
					 {"fields": [{"type": "STRING",
						 "name": "exchangeIdScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "specifiedExchangeId",
					 "mode": "REPEATED"}],
				 "type": "RECORD",
				 "name": "underlyingEquity",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "redemptionDate",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_ConvertibleBond_value",
			 "mode": "NULLABLE"},
			 {"fields": [{"type": "STRING",
				 "name": "id",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "instrumentIdScheme",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "instrumentId",
				 "mode": "REPEATED"},
				 {"type": "STRING",
				 "name": "description",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_IdentifiedCurrency_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "currencyScheme",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "keyValue",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Currency_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "currency",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "exchangeIdScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "exchangeId",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "clearanceSystemScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "clearanceSystem",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "definition",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "issuerName",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "href",
					 "mode": "REQUIRED"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "issuerPartyReference",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "creditSeniorityScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "seniority",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "couponTypeScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "couponType",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "couponRate",
				 "mode": "NULLABLE"},
				 {"type": "STRING",
				 "name": "maturity",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "parValue",
				 "mode": "NULLABLE"},
				 {"type": "FLOAT",
				 "name": "faceAmount",
				 "mode": "NULLABLE"},
				 {"fields": [{"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Period_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_Offset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_RelativeDateOffset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodSkip",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "unadjustedFirstDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "unadjustedLastDate",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_DateRange_value",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "unadjustedFirstDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "unadjustedLastDate",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "businessDayConvention",
								 "mode": "REQUIRED"},
								 {"fields": [{"type": "STRING",
									 "name": "href",
									 "mode": "REQUIRED"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCentersReference",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"fields": [{"type": "STRING",
										 "name": "businessCenterScheme",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "id",
										 "mode": "NULLABLE"},
										 {"type": "STRING",
										 "name": "keyValue",
										 "mode": "REQUIRED"}],
									 "type": "RECORD",
									 "name": "businessCenter",
									 "mode": "REPEATED"}],
								 "type": "RECORD",
								 "name": "businessCenters",
								 "mode": "NULLABLE"}],
							 "type": "RECORD",
							 "name": "org_fpml_fpml_5_BusinessDateRange_value",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "scheduleBounds",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_RelativeDates_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "dateRelativeTo",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "adjustedDate",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"type": "STRING",
							 "name": "businessDayConvention",
							 "mode": "REQUIRED"},
							 {"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCentersReference",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"fields": [{"type": "STRING",
									 "name": "businessCenterScheme",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "id",
									 "mode": "NULLABLE"},
									 {"type": "STRING",
									 "name": "keyValue",
									 "mode": "REQUIRED"}],
								 "type": "RECORD",
								 "name": "businessCenter",
								 "mode": "REPEATED"}],
							 "type": "RECORD",
							 "name": "businessCenters",
							 "mode": "NULLABLE"}],
						 "type": "RECORD",
						 "name": "relativeDateAdjustments",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_AdjustedRelativeDateOffset_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"},
						 {"fields": [{"type": "STRING",
							 "name": "href",
							 "mode": "REQUIRED"},
							 {"type": "STRING",
							 "name": "keyValue",
							 "mode": "REQUIRED"}],
						 "type": "RECORD",
						 "name": "businessCentersReference",
						 "mode": "NULLABLE"},
						 {"fields": [{"type": "STRING",
							 "name": "id",
							 "mode": "NULLABLE"},
							 {"fields": [{"type": "STRING",
								 "name": "businessCenterScheme",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "id",
								 "mode": "NULLABLE"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "businessCenter",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "businessCenters",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "paymentDatesReference",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "dateRelativeToPaymentDates",
						 "mode": "NULLABLE"},
						 {"fields": [{"fields": [{"type": "STRING",
								 "name": "href",
								 "mode": "REQUIRED"},
								 {"type": "STRING",
								 "name": "keyValue",
								 "mode": "REQUIRED"}],
							 "type": "RECORD",
							 "name": "calculationPeriodDatesReference",
							 "mode": "REPEATED"}],
						 "type": "RECORD",
						 "name": "dateRelativeToCalculationPeriodDates",
						 "mode": "NULLABLE"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_FxFixingDate_value",
					 "mode": "NULLABLE"},
					 {"fields": [{"type": "STRING",
						 "name": "id",
						 "mode": "NULLABLE"},
						 {"type": "INTEGER",
						 "name": "periodMultiplier",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "period",
						 "mode": "REQUIRED"},
						 {"type": "STRING",
						 "name": "dayType",
						 "mode": "NULLABLE"},
						 {"type": "STRING",
						 "name": "businessDayConvention",
						 "mode": "REQUIRED"}],
					 "type": "RECORD",
					 "name": "org_fpml_fpml_5_DateOffset_value",
					 "mode": "NULLABLE"}],
				 "type": "RECORD",
				 "name": "paymentFrequency",
				 "mode": "NULLABLE"},
				 {"fields": [{"type": "STRING",
					 "name": "dayCountFractionScheme",
					 "mode": "NULLABLE"},
					 {"type": "STRING",
					 "name": "keyValue",
					 "mode": "REQUIRED"}],
				 "type": "RECORD",
				 "name": "dayCountFraction",
				 "mode": "NULLABLE"}],
			 "type": "RECORD",
			 "name": "org_fpml_fpml_5_Bond_value",
			 "mode": "NULLABLE"}],
		 "type": "RECORD",
		 "name": "convertibleBond",
		 "mode": "NULLABLE"}]}}

    def test_toDict(self):
        schema2Dict = (
                bigquery.SchemaField('string', 'STRING'),
                bigquery.SchemaField('integer', 'INTEGER'),
                bigquery.SchemaField('float', 'FLOAT'),
                bigquery.SchemaField('boolean', 'BOOLEAN'),
                bigquery.SchemaField('record', 'RECORD',fields=(
                        bigquery.SchemaField('string2', 'STRING'),
                        bigquery.SchemaField('float', 'FLOAT'),
                        bigquery.SchemaField('integer2', 'INTEGER'),
                        bigquery.SchemaField('boolean2', 'BOOLEAN')
                        )),
               bigquery.SchemaField('array', 'RECORD',mode='REPEATED',fields=(
                       bigquery.SchemaField('string3', 'STRING'),
                       bigquery.SchemaField('integer3', 'INTEGER')
                       )) 
            )
        
        expectedResult = [{"name":'string',
                          "type":'STRING',
                          "description":None,
                          "mode":'NULLABLE',
                          "fields":[]},
                        {"name":'integer',
                          "type":'INTEGER',
                          "description":None,
                          "mode":'NULLABLE',
                          "fields":[]},
                         {"name":'float',
                          "type":'FLOAT',
                          "description":None,
                          "mode":'NULLABLE',
                          "fields":[]},
                        {"name":'boolean',
                          "type":'BOOLEAN',
                          "description":None,
                          "mode":'NULLABLE',
                          "fields":[]}, 
                        {"name":'record',
                          "type":'RECORD',
                          "description":None,
                          "mode":'NULLABLE',
                          "fields":[
                                 {"name":'string2',
                                  "type":'STRING',
                                  "description":None,
                                  "mode":'NULLABLE',
                                  "fields":[]}, 
                                 {"name":'float',
                                  "type":'FLOAT',
                                  "description":None,
                                  "mode":'NULLABLE',
                                  "fields":[]},
                                 {"name":'integer2',
                                  "type":'INTEGER',
                                  "description":None,
                                  "mode":'NULLABLE',
                                  "fields":[]},
                                 {"name":'boolean2',
                                  "type":'BOOLEAN',
                                  "description":None,
                                  "mode":'NULLABLE',
                                  "fields":[]}
                                  ]},
                        {"name":'array',
                          "type":'RECORD',
                          "description":None,
                          "mode":'REPEATED',
                          "fields":[
                                 {"name":'string3',
                                  "type":'STRING',
                                  "description":None,
                                  "mode":'NULLABLE',
                                  "fields":[]}, 
                                 {"name":'integer3',
                                  "type":'INTEGER',
                                  "description":None,
                                  "mode":'NULLABLE',
                                  "fields":[]}
                                  ]} 
                         ]
        sa=[]
        
        # print("showing each field")
        for bqi in schema2Dict:
            i = bqtools.to_dict(bqi)
            #self.pp.pprint(i)
            sa.append(i)
        diff = DeepDiff(expectedResult, sa, ignore_order=True)    
        self.assertEqual(diff,{}, "Unexpected result in toDict expected nothing insteadest got {}".format(self.pp.pprint(diff)))
        
    def test_createschema(self):
        bqSchema = bqtools.create_schema(self.schemaTest1)
        expectedSchema = (
                bigquery.SchemaField('string', 'STRING'),
                bigquery.SchemaField('integer', 'INTEGER'),
                bigquery.SchemaField('float', 'FLOAT'),
                bigquery.SchemaField('boolean', 'BOOLEAN'),
                bigquery.SchemaField('record', 'RECORD',fields=(
                        bigquery.SchemaField('string2', 'STRING'),
                        bigquery.SchemaField('float', 'FLOAT'),
                        bigquery.SchemaField('integer2', 'INTEGER'),
                        bigquery.SchemaField('boolean2', 'BOOLEAN')
                        )),
               bigquery.SchemaField('array', 'RECORD',mode='REPEATED',fields=(
                       bigquery.SchemaField('string3', 'STRING'),
                       bigquery.SchemaField('integer3', 'INTEGER')
                       )) 
            )
        
        
        

        # print("testing result")
        # self.pp.pprint(bqSchema)
        sa=[]
        
        # print("showing each field")
        for bqi in bqSchema:
            i = bqtools.to_dict(bqi)
            #self.pp.pprint(i)
            sa.append(i)
        # print("Schema as dict")
        #self.pp.pprint(sa)
        isa = sa
        
        # print("Expected result")
        #self.pp.pprint(expectedSchema)
        sa=[]
        
        # print("showing each expected field")
        for bqi in expectedSchema:
            i = bqtools.to_dict(bqi)
            # self.pp.pprint(i)
            sa.append(i)
        # print("expected Schema as dict")
        diff = DeepDiff(isa, sa, ignore_order=True)
        # self.pp.pprint(diff)
        a = "Schema test1 schema does not match target {}".format(len(diff))
        self.assertEqual(diff,{}, a)
        
        
    def test_createschema2(self):
        # print("Creating a new schema")

        bqSchema2 = bqtools.create_schema(self.schemaTest2)
        sa2=[]
        
        # print("showing each field schema2")
        for bqi in bqSchema2:
            i = bqtools.to_dict(bqi)
            # self.pp.pprint(i)
            sa2.append(i)
        # print("Schema2 as dict")
        # self.pp.pprint(sa2)
        expectedSchema2 = (
                bigquery.SchemaField('string', 'STRING'),
                bigquery.SchemaField('integer', 'INTEGER'),
                bigquery.SchemaField('record', 'RECORD',fields=(
                        bigquery.SchemaField('string2', 'STRING'),
                        bigquery.SchemaField('float', 'FLOAT'),
                        bigquery.SchemaField('boolean2', 'BOOLEAN'),
                        bigquery.SchemaField('appended1', 'STRING')
                        )),
               bigquery.SchemaField('array', 'RECORD',mode='REPEATED',fields=(
                       bigquery.SchemaField('string3', 'STRING'),
                       bigquery.SchemaField('integer3', 'INTEGER'),
                       bigquery.SchemaField('foo', 'FLOAT')
                       )) ,
               bigquery.SchemaField('anotherarray', 'RECORD',mode='REPEATED',fields=(
                       bigquery.SchemaField('test1', 'INTEGER'),
                       bigquery.SchemaField('test2', 'BOOLEAN')
                       )) 
            )
        sa = []
        for bqi in expectedSchema2:
            i = bqtools.to_dict(bqi)
            # self.pp.pprint(i)
            sa.append(i)
            
        diff = DeepDiff(sa, sa2, ignore_order=True)
        # self.pp.pprint(diff)
        a = "Schema test1 schema does not match target {}".format(diff)
        self.assertEqual(diff,{}, a)
        logger = logging.getLogger("testBQTools")

        evolved = bqtools.match_and_addtoschema({"string":"hello"},expectedSchema2,logger=logger)
        self.assertEqual(evolved,False,"Expected no evolve but got evolve true evolve test 1")
        evolved = bqtools.match_and_addtoschema({"string": "hello","integer":52}, expectedSchema2,logger=logger)
        self.assertEqual(evolved, False, "Expected no evolve but got evolve true evolve test 2")
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52, "record":{}}, expectedSchema2,logger=logger)
        self.assertEqual(evolved, False, "Expected no evolve but got evolve true evolve test 3")
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52, "record": {"string2":"hello2"}}, expectedSchema2,logger=logger)
        self.assertEqual(evolved, False, "Expected no evolve but got evolve true evolve test 4")
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52, "record": {"string2": "hello2","float":1.3,"boolean2":False,"appended1":"another string"}},
                                                   expectedSchema2,logger=logger)
        self.assertEqual(evolved, False, "Expected no evolve but got evolve true evolve test 6")

        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"}, "array": []},
                                                   expectedSchema2,logger=logger)
        self.assertEqual(evolved, False, "Expected no evolve but got evolve true evolve test 7")
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"},
                                                    "array": [{"string3": "hello"}]},
                                                   expectedSchema2,logger=logger)
        self.assertEqual(evolved, False, "Expected no evolve but got evolve true evolve test 8")
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"},
                                                    "array": [{"string3": "hello","integer3":42}]},
                                                   expectedSchema2,logger=logger)
        self.assertEqual(evolved, False, "Expected no evolve but got evolve true evolve test 9")
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"},
                                                    "array": [{"string3": "hello", "integer3": 42,"foo":3.141}]},
                                                   expectedSchema2,logger=logger)
        self.assertEqual(evolved, False, "Expected no evolve but got evolve true evolve test 10")
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"},
                                                    "array": [{"string3": "hello", "integer3": 42, "foo": 3.141},{"integer3": 42, "foo": 3.141}]},
                                                   expectedSchema2,logger=logger)
        self.assertEqual(evolved, False, "Expected no evolve but got evolve true evolve test 11")
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"},
                                                    "array": [{"string3": "hello", "integer3": 42, "foo": 3.141},
                                                              {"integer3": 42, "foo": 3.141}],
                                                    "anotherarray":[{"test1":52,"test2":False},{"test1":52,"test2":True}]},
                                                   expectedSchema2,logger=logger)
        self.assertEqual(evolved, False, "Expected no evolve but got evolve true evolve test 12")

        # evolve tests bbelow prepare baseline
        copyoforigschema = list(expectedSchema2)
        savedSchema = copy.deepcopy(copyoforigschema)


        sa = []
        for bqi in copyoforigschema:
            i = bqtools.to_dict(bqi)
            # self.pp.pprint(i)
            sa.append(i)


        # Evolutio test 1
        # add some stuff 2 layers down in an array
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"},
                                                    "array": [{"string3": "hello", "integer3": 42, "foo": 3.141},
                                                              {"integer3": 42, "foo": 3.141}],
                                                    "anotherarray": [{"test1": 52, "test2": False},
                                                                     {"test1": 52, "test2": True,"fred":"I am an evolved string","iamanotherevolve":32}]},
                                                   copyoforigschema,logger=logger)
        self.assertEqual(evolved, True, "Expected evolve but got no evolve False for evolve test 13")

        sa2 = []
        for bqi in copyoforigschema:
            i = bqtools.to_dict(bqi)
            # self.pp.pprint(i)
            sa2.append(i)

        diff = DeepDiff(sa, sa2, ignore_order=True)

        print("============================================ evolve test 1 diff start  ====================================")
        print("Patched schema diff {} change{}".format(self.pp.pformat(diff), evolved))
        print("============================================ evolve test 1 diff end  ====================================")

        self.assertEqual({   'iterable_item_added': {   'root[4]': {   'description': None,
                                              'fields': [   {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'test1',
                                                                'type': 'INTEGER'},
                                                            {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'test2',
                                                                'type': 'BOOLEAN'},
                                                            {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'iamanotherevolve',
                                                                'type': 'INTEGER'},
                                                            {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'fred',
                                                                'type': 'STRING'}],
                                              'mode': 'REPEATED',
                                              'name': 'anotherarray',
                                              'type': 'RECORD'}},
    'iterable_item_removed': {   'root[4]': {   'description': None,
                                                'fields': [   {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'test1',
                                                                  'type': 'INTEGER'},
                                                              {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'test2',
                                                                  'type': 'BOOLEAN'}],
                                                'mode': 'REPEATED',
                                                'name': 'anotherarray',
                                                'type': 'RECORD'}}},diff,"Schema evolution not as expected {}".format(self.pp.pformat(diff)))
        # Evolution test 2
        #  this just adds a fiedl at top level
        copyoforigschema = copy.deepcopy(savedSchema)
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "hellomike":3.1415926,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"},
                                                    "array": [{"string3": "hello", "integer3": 42, "foo": 3.141},
                                                              {"integer3": 42, "foo": 3.141}],
                                                    "anotherarray": [{"test1": 52, "test2": False},
                                                                     {"test1": 52, "test2": True}]},
                                                   copyoforigschema,logger=logger)
        self.assertEqual(evolved, True, "Expected evolve but got no evolve False for evolve test 14")

        sa2 = []
        for bqi in copyoforigschema:
            i = bqtools.to_dict(bqi)
            # self.pp.pprint(i)
            sa2.append(i)

        diff = DeepDiff(sa, sa2, ignore_order=True)

        print(
            "============================================ evolve test 2 diff start  ====================================")
        print("Patched schema diff {} change{}".format(self.pp.pformat(diff), evolved))
        print(
            "============================================ evolve test 2 diff end  ====================================")

        self.assertEqual({   'iterable_item_added': {   'root[5]': {   'description': None,
                                              'fields': [],
                                              'mode': 'NULLABLE',
                                              'name': 'hellomike',
                                              'type': 'FLOAT'}}}, diff,
                         "Schema evolution not as expected {}".format(self.pp.pformat(diff)))

        # Evolution test 3
        # this is an object with root schema evolution
        # Plus child objects with 2 different changes in them
        # plus another with both
        copyoforigschema = copy.deepcopy(savedSchema)
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "hellomike": 3.1415926,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"},
                                                    "array": [{"string3": "hello", "integer3": 42, "foo": 3.141},
                                                              {"integer3": 42, "foo": 3.141}],
                                                    "anotherarray": [{"test1": 52, "test2": False,"fred":"I am an evolution"},
                                                                     {"test1": 52, "test2": True,"iamanotherevolution":1.3},
                                                                     {"test1": 52, "test2": True, "iamanotherevolution":1.3,"fred":"I am same previous evolution"}]},
                                                   copyoforigschema,logger=logger)
        self.assertEqual(evolved, True, "Expected evolve but got no evolve False for evolve test 14")

        sa2 = []
        for bqi in copyoforigschema:
            i = bqtools.to_dict(bqi)
            # self.pp.pprint(i)
            sa2.append(i)

        diff = DeepDiff(sa, sa2, ignore_order=True)

        print(
            "============================================ evolve test 3 diff start  ====================================")
        print("Patched schema diff {} change{}".format(self.pp.pformat(diff), evolved))
        print(
            "============================================ evolve test 3 diff end  ====================================")

        self.assertEqual({'iterable_item_added': {   'root[4]': {   'description': None,
                                              'fields': [   {   'description': None,
                                                                'fields': [],
                                                                'mode': 'NULLABLE',
                                                                'name': 'test1',
                                                                'type': 'INTEGER'},
                                                            {   'description': None,
                                                                'fields': [],
                                                                'mode': 'NULLABLE',
                                                                'name': 'test2',
                                                                'type': 'BOOLEAN'},
                                                            {   'description': None,
                                                                'fields': [],
                                                                'mode': 'NULLABLE',
                                                                'name': 'fred',
                                                                'type': 'STRING'},
                                                            {   'description': None,
                                                                'fields': [],
                                                                'mode': 'NULLABLE',
                                                                'name': 'iamanotherevolution',
                                                                'type': 'FLOAT'}],
                                              'mode': 'REPEATED',
                                              'name': 'anotherarray',
                                              'type': 'RECORD'},
                               'root[5]': {   'description': None,
                                              'fields': [],
                                              'mode': 'NULLABLE',
                                              'name': 'hellomike',
                                              'type': 'FLOAT'}},
                         'iterable_item_removed': {   'root[4]': {   'description': None,
                                                'fields': [   {   'description': None,
                                                                  'fields': [],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'test1',
                                                                  'type': 'INTEGER'},
                                                              {   'description': None,
                                                                  'fields': [],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'test2',
                                                                  'type': 'BOOLEAN'}],
                                                'mode': 'REPEATED',
                                                'name': 'anotherarray',
                                                'type': 'RECORD'}}}, diff,
                         "Schema evolution not as expected {}".format(self.pp.pformat(diff)))
        # Evolution test 4
        # this is an object with root schema evolution
        # Plus child objects with 2 different changes in them
        copyoforigschema = copy.deepcopy(savedSchema)
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "hellomike": 3.1415926,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"},
                                                    "array": [{"string3": "hello", "integer3": 42, "foo": 3.141},
                                                              {"integer3": 42, "foo": 3.141}],
                                                    "anotherarray": [
                                                        {"test1": 52, "test2": False, "fred": "I am an evolution"},
                                                        {"test1": 52, "test2": True, "iamanotherevolution": 1.3}]},
                                                   copyoforigschema,logger=logger)
        self.assertEqual(evolved, True, "Expected evolve but got no evolve False for evolve test 14")

        sa2 = []
        for bqi in copyoforigschema:
            i = bqtools.to_dict(bqi)
            # self.pp.pprint(i)
            sa2.append(i)

        diff = DeepDiff(sa, sa2, ignore_order=True)

        print(
            "============================================ evolve test 4 diff start  ====================================")
        print("Patched schema diff {} change{}".format(self.pp.pformat(diff), evolved))
        print(
            "============================================ evolve test 4 diff end  ====================================")

        self.assertEqual({'iterable_item_added': {'root[4]': {'description': None,
                                                              'fields': [{'description': None,
                                                                          'fields': [],
                                                                          'mode': 'NULLABLE',
                                                                          'name': 'test1',
                                                                          'type': 'INTEGER'},
                                                                         {'description': None,
                                                                          'fields': [],
                                                                          'mode': 'NULLABLE',
                                                                          'name': 'test2',
                                                                          'type': 'BOOLEAN'},
                                                                         {'description': None,
                                                                          'fields': [],
                                                                          'mode': 'NULLABLE',
                                                                          'name': 'fred',
                                                                          'type': 'STRING'},
                                                                         {'description': None,
                                                                          'fields': [],
                                                                          'mode': 'NULLABLE',
                                                                          'name': 'iamanotherevolution',
                                                                          'type': 'FLOAT'}],
                                                              'mode': 'REPEATED',
                                                              'name': 'anotherarray',
                                                              'type': 'RECORD'},
                                                  'root[5]': {'description': None,
                                                              'fields': [],
                                                              'mode': 'NULLABLE',
                                                              'name': 'hellomike',
                                                              'type': 'FLOAT'}},
                          'iterable_item_removed': {'root[4]': {'description': None,
                                                                'fields': [{'description': None,
                                                                            'fields': [],
                                                                            'mode': 'NULLABLE',
                                                                            'name': 'test1',
                                                                            'type': 'INTEGER'},
                                                                           {'description': None,
                                                                            'fields': [],
                                                                            'mode': 'NULLABLE',
                                                                            'name': 'test2',
                                                                            'type': 'BOOLEAN'}],
                                                                'mode': 'REPEATED',
                                                                'name': 'anotherarray',
                                                                'type': 'RECORD'}}}, diff,
                         "Schema evolution not as expected")
        # Evolution test 5
        # add an array with strings an dno key this should fail
        copyoforigschema = copy.deepcopy(savedSchema)
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "hellomike": 3.1415926,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"},
                                                    "array": [{"string3": "hello", "integer3": 42, "foo": 3.141},
                                                              {"integer3": 42, "foo": 3.141}],
                                                    "anotherarray": [
                                                        {"test1": 52, "test2": False, "fred": "I am an evolution"},
                                                        {"test1": 52, "test2": True, "iamanotherevolution": 1.3},
                                                        {"test1": 52, "test2": True, "iamanotherevolution": 1.3,"bill":["hello","fred","break this"]}]},
                                                   copyoforigschema,logger=logger)
        self.assertEqual(evolved, True, "Expected evolve but got no evolve False for evolve test 14")

        sa2 = []
        for bqi in copyoforigschema:
            i = bqtools.to_dict(bqi)
            # self.pp.pprint(i)
            sa2.append(i)

        diff = DeepDiff(sa, sa2, ignore_order=True)

        print(
            "============================================ evolve test 5 diff start  ====================================")
        print("Patched schema diff {} change{}".format(self.pp.pformat(diff), evolved))
        print(
            "============================================ evolve test 5 diff end  ====================================")

        self.assertEqual({  'iterable_item_added': {   'root[4]': {   'description': None,
                                              'fields': [   {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'test1',
                                                                'type': 'INTEGER'},
                                                            {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'test2',
                                                                'type': 'BOOLEAN'},
                                                            {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'fred',
                                                                'type': 'STRING'},
                                                            {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'iamanotherevolution',
                                                                'type': 'FLOAT'},
                                                            {   'description': None,
                                                                'fields': [   {   'description': None,
                                                                                  'fields': [   ],
                                                                                  'mode': 'NULLABLE',
                                                                                  'name': 'value',
                                                                                  'type': 'STRING'}],
                                                                'mode': 'REPEATED',
                                                                'name': 'bill',
                                                                'type': 'RECORD'}],
                                              'mode': 'REPEATED',
                                              'name': 'anotherarray',
                                              'type': 'RECORD'},
                               'root[5]': {   'description': None,
                                              'fields': [],
                                              'mode': 'NULLABLE',
                                              'name': 'hellomike',
                                              'type': 'FLOAT'}},
    'iterable_item_removed': {   'root[4]': {   'description': None,
                                                'fields': [   {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'test1',
                                                                  'type': 'INTEGER'},
                                                              {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'test2',
                                                                  'type': 'BOOLEAN'}],
                                                'mode': 'REPEATED',
                                                'name': 'anotherarray',
                                                'type': 'RECORD'}}}, diff,
                         "Schema evolution not as expected")

        # Evolution test 6
        # add an array with strings an dno key this should fail
        copyoforigschema = copy.deepcopy(savedSchema)
        evolved = bqtools.match_and_addtoschema({"string": "hello", "integer": 52,
                                                    "hellomike": 3.1415926,
                                                    "record": {"string2": "hello2", "float": 1.3, "boolean2": False,
                                                               "appended1": "another string"},
                                                    "array": [{"string3": "hello", "integer3": 42, "foo": 3.141},
                                                              {"integer3": 42, "foo": 3.141}],
                                                    "anotherarray": [
                                                        {"test1": 52, "test2": False, "fred": "I am an evolution"},
                                                        {"test1": 52, "test2": True, "iamanotherevolution": 1.3},
                                                        {"test1": 52, "test2": True, "iamanotherevolution": 1.3,
                                                         "bill": {}}]},
                                                   copyoforigschema,logger=logger)
        self.assertEqual(evolved, True, "Expected evolve but got no evolve False for evolve test 14")

        sa2 = []
        for bqi in copyoforigschema:
            i = bqtools.to_dict(bqi)
            # self.pp.pprint(i)
            sa2.append(i)

        diff = DeepDiff(sa, sa2, ignore_order=True)

        print(
            "============================================ evolve test 6 diff start  ====================================")
        print("Patched schema diff {} change{}".format(self.pp.pformat(diff), evolved))
        print(
            "============================================ evolve test 6 diff end  ====================================")

        self.assertEqual({'iterable_item_added': {'root[4]': {'description': None,
                                                              'fields': [{'description': None,
                                                                          'fields': [],
                                                                          'mode': 'NULLABLE',
                                                                          'name': 'test1',
                                                                          'type': 'INTEGER'},
                                                                         {'description': None,
                                                                          'fields': [],
                                                                          'mode': 'NULLABLE',
                                                                          'name': 'test2',
                                                                          'type': 'BOOLEAN'},
                                                                         {'description': None,
                                                                          'fields': [],
                                                                          'mode': 'NULLABLE',
                                                                          'name': 'fred',
                                                                          'type': 'STRING'},
                                                                         {'description': None,
                                                                          'fields': [],
                                                                          'mode': 'NULLABLE',
                                                                          'name': 'iamanotherevolution',
                                                                          'type': 'FLOAT'},
                                                                         {'description': None,
                                                                          'fields': [{'description': None,
                                                                                      'fields': [],
                                                                                      'mode': 'NULLABLE',
                                                                                      'name': 'xxxDummySchemaAsNoneDefinedxxx',
                                                                                      'type': 'STRING'}],
                                                                          'mode': 'NULLABLE',
                                                                          'name': 'bill',
                                                                          'type': 'RECORD'}],
                                                              'mode': 'REPEATED',
                                                              'name': 'anotherarray',
                                                              'type': 'RECORD'},
                                                  'root[5]': {'description': None,
                                                              'fields': [],
                                                              'mode': 'NULLABLE',
                                                              'name': 'hellomike',
                                                              'type': 'FLOAT'}},
                          'iterable_item_removed': {'root[4]': {'description': None,
                                                                'fields': [{'description': None,
                                                                            'fields': [],
                                                                            'mode': 'NULLABLE',
                                                                            'name': 'test1',
                                                                            'type': 'INTEGER'},
                                                                           {'description': None,
                                                                            'fields': [],
                                                                            'mode': 'NULLABLE',
                                                                            'name': 'test2',
                                                                            'type': 'BOOLEAN'}],
                                                                'mode': 'REPEATED',
                                                                'name': 'anotherarray',
                                                                'type': 'RECORD'}}}, diff,
                         "Schema evolution not as expected")

    def test_patchbare(self):
        startschema = bqtools.create_schema(self.schema2startnobare)
        resultschema = bqtools.create_schema(self.schemaTest2nonbare)

        origobject = copy.deepcopy(self.schemaTest2bare)

        evolved = bqtools.match_and_addtoschema(self.schemaTest2bare, startschema)
        self.assertEqual(evolved, True,"Bare llist and multi dict evolution has not happened as expected")
        diff = DeepDiff(resultschema, startschema, ignore_order=True)

        print(
            "============================================ mixed arrays added  diff start  ====================================")
        print("Patched schema diff {} change{}".format(self.pp.pformat(diff), evolved))
        print(
            "============================================ mixed arrays added  diff end  ====================================")



    def test_patch(self):
        
        bqSchema2 = bqtools.create_schema(self.schemaTest2)   
        bqSchema = bqtools.create_schema(self.schemaTest1)
        
        sa=[]
        
        
        for bqi in bqSchema:
            i = bqtools.to_dict(bqi)
            sa.append(i)
            
        osa = copy.deepcopy(sa)
            
        change,pschema = bqtools.recurse_and_add_to_schema(bqSchema2,sa)
        diff = DeepDiff( pschema,osa, ignore_order=True)
        
        # patching never removes fields so expect additions
        # so after list of root[] should be one longer
        expectedDiff = {   'iterable_item_added': {   'root[2]': {   'description': None,
                                              'fields': [   {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'integer2',
                                                                'type': 'INTEGER'},
                                                            {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'float',
                                                                'type': 'FLOAT'},
                                                            {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'string2',
                                                                'type': 'STRING'},
                                                            {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'boolean2',
                                                                'type': 'BOOLEAN'}],
                                              'mode': 'NULLABLE',
                                              'name': 'record',
                                              'type': 'RECORD'},
                               'root[5]': {   'description': None,
                                              'fields': [   {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'integer3',
                                                                'type': 'INTEGER'},
                                                            {   'description': None,
                                                                'fields': [   ],
                                                                'mode': 'NULLABLE',
                                                                'name': 'string3',
                                                                'type': 'STRING'}],
                                              'mode': 'REPEATED',
                                              'name': 'array',
                                              'type': 'RECORD'}},
    'iterable_item_removed': {   'root[2]': {   'description': None,
                                                'fields': [   {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'integer2',
                                                                  'type': 'INTEGER'},
                                                              {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'float',
                                                                  'type': 'FLOAT'},
                                                              {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'string2',
                                                                  'type': 'STRING'},
                                                              {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'boolean2',
                                                                  'type': 'BOOLEAN'},
                                                              {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'appended1',
                                                                  'type': 'STRING'}],
                                                'mode': 'NULLABLE',
                                                'name': 'record',
                                                'type': 'RECORD'},
                                 'root[5]': {   'description': None,
                                                'fields': [   {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'integer3',
                                                                  'type': 'INTEGER'},
                                                              {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'string3',
                                                                  'type': 'STRING'},
                                                              {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'foo',
                                                                  'type': 'FLOAT'}],
                                                'mode': 'REPEATED',
                                                'name': 'array',
                                                'type': 'RECORD'},
                                 'root[6]': {   'description': None,
                                                'fields': [   {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'test1',
                                                                  'type': 'INTEGER'},
                                                              {   'description': None,
                                                                  'fields': [   ],
                                                                  'mode': 'NULLABLE',
                                                                  'name': 'test2',
                                                                  'type': 'BOOLEAN'}],
                                                'mode': 'REPEATED',
                                                'name': 'anotherarray',
                                                'type': 'RECORD'}}}
        
        self.assertEqual(diff,expectedDiff, "Patch diff is not what is expected {}".format(self.pp.pformat(diff)))  
        self.assertEqual(change,True, "Patch diff change result {} is not what is expected {}".format(change,self.pp.pformat(diff))) 
        
        bqSchema3 = bqtools.create_schema(self.schemaTest3)   
        bqSchema4 = bqtools.create_schema(self.schemaTest4)
        
        sa2=[]
        
        
        for bqi in bqSchema3:
            i = bqtools.to_dict(bqi)
            sa2.append(i)
            
        osa = copy.deepcopy(sa2)
            
        change,pschema = bqtools.recurse_and_add_to_schema(bqSchema4,sa2)
        diff = DeepDiff( pschema,osa, ignore_order=True)
        print("Patched schema diff {} change{}".format(self.pp.pformat(diff),change))
#        print("old {}".format(self.pp.pformat(osa)))
#        print("new {}".format(self.pp.pformat(pschema)))

    def test_patch2(self):
        
        bqSchema2 = bqtools.create_schema(self.schemaTest2)   
        bqSchema = bqtools.create_schema(self.schemaTest2)
        
        sa=[]
        
        
        for bqi in bqSchema:
            i = bqtools.to_dict(bqi)
            sa.append(i)
            
        osa = copy.deepcopy(sa)
            
        change,pschema = bqtools.recurse_and_add_to_schema(bqSchema2,sa)
        diff = DeepDiff( pschema,osa, ignore_order=True)
        
        # patching never removes fields so expect additions
        # so after list of root[] should be one longer
        expectedDiff = {  }
        
        self.assertEqual(diff,expectedDiff, "Patch diff is not what is expected {}".format(self.pp.pformat(diff)))  
        
        self.assertEqual(change,False, "Patch diff change result {} is not what is expected {}".format(change,self.pp.pformat(diff)))  
#        print("Patched schema diff {}".format(self.pp.pformat(diff)))
#        print("old {}".format(self.pp.pformat(osa)))
#        print("new {}".format(self.pp.pformat(pschema)))

    def test_gendiff(self):
        bqSchema2 = bqtools.create_schema(self.schemaTest2)
        views=bqtools.gen_diff_views('foo','ar','bob',bqSchema2,description="A test schema")
        
        vexpected = { 'bobdb' : {
                          "query" : """#standardSQL
SELECT
    _PARTITIONTIME AS scantime,
    ifnull(tabob.integer,0) as integer,
    ifnull(A1.integer3,0) as arrayinteger3,
    ifnull(A1.foo,0.0) as arrayfoo,
    ifnull(A1.string3,"None") as arraystring3,
    ifnull(A2.test1,0) as anotherarraytest1,
    ifnull(A2.test2,False) as anotherarraytest2,
    ifnull(tabob.string,"None") as string,
    ifnull(tabob.record.appended1,"None") as recordappended1,
    ifnull(tabob.record.float,0.0) as recordfloat,
    ifnull(tabob.record.string2,"None") as recordstring2,
    ifnull(tabob.record.boolean2,False) as recordboolean2
from `foo.ar.bob` as tabob
LEFT JOIN UNNEST(tabob.array) as A1
LEFT JOIN UNNEST(tabob.anotherarray) as A2""",
                         "description":"View used as basis for diffview:A test schema"},
                     'bobdiffday' : { 
                        "query":"""#standardSQL
SELECT
    o.scantime as origscantime,
    l.scantime as laterscantime,
    CASE
    WHEN o.integer IS NULL THEN 'Added'
    WHEN l.integer IS NULL THEN 'Deleted'
    WHEN o.integer = l.integer AND o.arrayinteger3 = l.arrayinteger3 AND o.arrayfoo = l.arrayfoo AND o.arraystring3 = l.arraystring3 AND o.anotherarraytest1 = l.anotherarraytest1 AND o.anotherarraytest2 = l.anotherarraytest2 AND o.string = l.string AND o.recordappended1 = l.recordappended1 AND o.recordfloat = l.recordfloat AND o.recordstring2 = l.recordstring2 AND o.recordboolean2 = l.recordboolean2 THEN 'Same'
    ELSE 'Updated'
  END AS action,
    o.integer as originteger,
    l.integer as laterinteger,
    case when o.integer = l.integer then 0 else 1 end as diffinteger,
    o.arrayinteger3 as origarrayinteger3,
    l.arrayinteger3 as laterarrayinteger3,
    case when o.arrayinteger3 = l.arrayinteger3 then 0 else 1 end as diffarrayinteger3,
    o.arrayfoo as origarrayfoo,
    l.arrayfoo as laterarrayfoo,
    case when o.arrayfoo = l.arrayfoo then 0 else 1 end as diffarrayfoo,
    o.arraystring3 as origarraystring3,
    l.arraystring3 as laterarraystring3,
    case when o.arraystring3 = l.arraystring3 then 0 else 1 end as diffarraystring3,
    o.anotherarraytest1 as origanotherarraytest1,
    l.anotherarraytest1 as lateranotherarraytest1,
    case when o.anotherarraytest1 = l.anotherarraytest1 then 0 else 1 end as diffanotherarraytest1,
    o.anotherarraytest2 as origanotherarraytest2,
    l.anotherarraytest2 as lateranotherarraytest2,
    case when o.anotherarraytest2 = l.anotherarraytest2 then 0 else 1 end as diffanotherarraytest2,
    o.string as origstring,
    l.string as laterstring,
    case when o.string = l.string then 0 else 1 end as diffstring,
    o.recordappended1 as origrecordappended1,
    l.recordappended1 as laterrecordappended1,
    case when o.recordappended1 = l.recordappended1 then 0 else 1 end as diffrecordappended1,
    o.recordfloat as origrecordfloat,
    l.recordfloat as laterrecordfloat,
    case when o.recordfloat = l.recordfloat then 0 else 1 end as diffrecordfloat,
    o.recordstring2 as origrecordstring2,
    l.recordstring2 as laterrecordstring2,
    case when o.recordstring2 = l.recordstring2 then 0 else 1 end as diffrecordstring2,
    o.recordboolean2 as origrecordboolean2,
    l.recordboolean2 as laterrecordboolean2,
    case when o.recordboolean2 = l.recordboolean2 then 0 else 1 end as diffrecordboolean2
  FROM (SELECT
     *
  FROM
    `foo.ar.bobdb`
  WHERE
    scantime = (
    SELECT
      MAX(_PARTITIONTIME)
    FROM
      `foo.ar.bob`
    WHERE
      scantime < (
      SELECT
        MAX(_PARTITIONTIME)
      FROM
        `foo.ar.bob`)
      AND
      _PARTITIONTIME < TIMESTAMP_SUB(CURRENT_TIMESTAMP(),INTERVAL 1 DAY) ) ) o
FULL OUTER JOIN (
  SELECT
     *
  FROM
    `foo.ar.bobdb`
  WHERE
    scantime =(
    SELECT
      MAX(_PARTITIONTIME)
    FROM
      `foo.ar.bob` )) l
ON
    l.integer = o.integer
    AND l.arrayinteger3=o.arrayinteger3
    AND l.arrayfoo=o.arrayfoo
    AND l.arraystring3=o.arraystring3
    AND l.anotherarraytest1=o.anotherarraytest1
    AND l.anotherarraytest2=o.anotherarraytest2
    AND l.string=o.string
    AND l.recordappended1=o.recordappended1
    AND l.recordfloat=o.recordfloat
    AND l.recordstring2=o.recordstring2
    AND l.recordboolean2=o.recordboolean2""",
                        "description":"Diff of day of underlying table bob description: A test schema"},
                'bobdiffweek':{'query':"""#standardSQL
SELECT
    o.scantime as origscantime,
    l.scantime as laterscantime,
    CASE
    WHEN o.integer IS NULL THEN 'Added'
    WHEN l.integer IS NULL THEN 'Deleted'
    WHEN o.integer = l.integer AND o.arrayinteger3 = l.arrayinteger3 AND o.arrayfoo = l.arrayfoo AND o.arraystring3 = l.arraystring3 AND o.anotherarraytest1 = l.anotherarraytest1 AND o.anotherarraytest2 = l.anotherarraytest2 AND o.string = l.string AND o.recordappended1 = l.recordappended1 AND o.recordfloat = l.recordfloat AND o.recordstring2 = l.recordstring2 AND o.recordboolean2 = l.recordboolean2 THEN 'Same'
    ELSE 'Updated'
  END AS action,
    o.integer as originteger,
    l.integer as laterinteger,
    case when o.integer = l.integer then 0 else 1 end as diffinteger,
    o.arrayinteger3 as origarrayinteger3,
    l.arrayinteger3 as laterarrayinteger3,
    case when o.arrayinteger3 = l.arrayinteger3 then 0 else 1 end as diffarrayinteger3,
    o.arrayfoo as origarrayfoo,
    l.arrayfoo as laterarrayfoo,
    case when o.arrayfoo = l.arrayfoo then 0 else 1 end as diffarrayfoo,
    o.arraystring3 as origarraystring3,
    l.arraystring3 as laterarraystring3,
    case when o.arraystring3 = l.arraystring3 then 0 else 1 end as diffarraystring3,
    o.anotherarraytest1 as origanotherarraytest1,
    l.anotherarraytest1 as lateranotherarraytest1,
    case when o.anotherarraytest1 = l.anotherarraytest1 then 0 else 1 end as diffanotherarraytest1,
    o.anotherarraytest2 as origanotherarraytest2,
    l.anotherarraytest2 as lateranotherarraytest2,
    case when o.anotherarraytest2 = l.anotherarraytest2 then 0 else 1 end as diffanotherarraytest2,
    o.string as origstring,
    l.string as laterstring,
    case when o.string = l.string then 0 else 1 end as diffstring,
    o.recordappended1 as origrecordappended1,
    l.recordappended1 as laterrecordappended1,
    case when o.recordappended1 = l.recordappended1 then 0 else 1 end as diffrecordappended1,
    o.recordfloat as origrecordfloat,
    l.recordfloat as laterrecordfloat,
    case when o.recordfloat = l.recordfloat then 0 else 1 end as diffrecordfloat,
    o.recordstring2 as origrecordstring2,
    l.recordstring2 as laterrecordstring2,
    case when o.recordstring2 = l.recordstring2 then 0 else 1 end as diffrecordstring2,
    o.recordboolean2 as origrecordboolean2,
    l.recordboolean2 as laterrecordboolean2,
    case when o.recordboolean2 = l.recordboolean2 then 0 else 1 end as diffrecordboolean2
  FROM (SELECT
     *
  FROM
    `foo.ar.bobdb`
  WHERE
    scantime = (
    SELECT
      MAX(_PARTITIONTIME)
    FROM
      `foo.ar.bob`
    WHERE
      scantime < (
      SELECT
        MAX(_PARTITIONTIME)
      FROM
        `foo.ar.bob`)
      AND
      _PARTITIONTIME < TIMESTAMP_SUB(CURRENT_TIMESTAMP(),INTERVAL 7 DAY) ) ) o
FULL OUTER JOIN (
  SELECT
     *
  FROM
    `foo.ar.bobdb`
  WHERE
    scantime =(
    SELECT
      MAX(_PARTITIONTIME)
    FROM
      `foo.ar.bob` )) l
ON
    l.integer = o.integer
    AND l.arrayinteger3=o.arrayinteger3
    AND l.arrayfoo=o.arrayfoo
    AND l.arraystring3=o.arraystring3
    AND l.anotherarraytest1=o.anotherarraytest1
    AND l.anotherarraytest2=o.anotherarraytest2
    AND l.string=o.string
    AND l.recordappended1=o.recordappended1
    AND l.recordfloat=o.recordfloat
    AND l.recordstring2=o.recordstring2
    AND l.recordboolean2=o.recordboolean2""",
                    'description':'Diff of week of underlying table bob description: A test schema'},
                'bobdiffmonth':{'query':"""#standardSQL
SELECT
    o.scantime as origscantime,
    l.scantime as laterscantime,
    CASE
    WHEN o.integer IS NULL THEN 'Added'
    WHEN l.integer IS NULL THEN 'Deleted'
    WHEN o.integer = l.integer AND o.arrayinteger3 = l.arrayinteger3 AND o.arrayfoo = l.arrayfoo AND o.arraystring3 = l.arraystring3 AND o.anotherarraytest1 = l.anotherarraytest1 AND o.anotherarraytest2 = l.anotherarraytest2 AND o.string = l.string AND o.recordappended1 = l.recordappended1 AND o.recordfloat = l.recordfloat AND o.recordstring2 = l.recordstring2 AND o.recordboolean2 = l.recordboolean2 THEN 'Same'
    ELSE 'Updated'
  END AS action,
    o.integer as originteger,
    l.integer as laterinteger,
    case when o.integer = l.integer then 0 else 1 end as diffinteger,
    o.arrayinteger3 as origarrayinteger3,
    l.arrayinteger3 as laterarrayinteger3,
    case when o.arrayinteger3 = l.arrayinteger3 then 0 else 1 end as diffarrayinteger3,
    o.arrayfoo as origarrayfoo,
    l.arrayfoo as laterarrayfoo,
    case when o.arrayfoo = l.arrayfoo then 0 else 1 end as diffarrayfoo,
    o.arraystring3 as origarraystring3,
    l.arraystring3 as laterarraystring3,
    case when o.arraystring3 = l.arraystring3 then 0 else 1 end as diffarraystring3,
    o.anotherarraytest1 as origanotherarraytest1,
    l.anotherarraytest1 as lateranotherarraytest1,
    case when o.anotherarraytest1 = l.anotherarraytest1 then 0 else 1 end as diffanotherarraytest1,
    o.anotherarraytest2 as origanotherarraytest2,
    l.anotherarraytest2 as lateranotherarraytest2,
    case when o.anotherarraytest2 = l.anotherarraytest2 then 0 else 1 end as diffanotherarraytest2,
    o.string as origstring,
    l.string as laterstring,
    case when o.string = l.string then 0 else 1 end as diffstring,
    o.recordappended1 as origrecordappended1,
    l.recordappended1 as laterrecordappended1,
    case when o.recordappended1 = l.recordappended1 then 0 else 1 end as diffrecordappended1,
    o.recordfloat as origrecordfloat,
    l.recordfloat as laterrecordfloat,
    case when o.recordfloat = l.recordfloat then 0 else 1 end as diffrecordfloat,
    o.recordstring2 as origrecordstring2,
    l.recordstring2 as laterrecordstring2,
    case when o.recordstring2 = l.recordstring2 then 0 else 1 end as diffrecordstring2,
    o.recordboolean2 as origrecordboolean2,
    l.recordboolean2 as laterrecordboolean2,
    case when o.recordboolean2 = l.recordboolean2 then 0 else 1 end as diffrecordboolean2
  FROM (SELECT
     *
  FROM
    `foo.ar.bobdb`
  WHERE
    scantime = (
    SELECT
      MAX(_PARTITIONTIME)
    FROM
      `foo.ar.bob`
    WHERE
      scantime < (
      SELECT
        MAX(_PARTITIONTIME)
      FROM
        `foo.ar.bob`)
      AND
      _PARTITIONTIME < TIMESTAMP_SUB(CURRENT_TIMESTAMP(),INTERVAL 30 DAY) ) ) o
FULL OUTER JOIN (
  SELECT
     *
  FROM
    `foo.ar.bobdb`
  WHERE
    scantime =(
    SELECT
      MAX(_PARTITIONTIME)
    FROM
      `foo.ar.bob` )) l
ON
    l.integer = o.integer
    AND l.arrayinteger3=o.arrayinteger3
    AND l.arrayfoo=o.arrayfoo
    AND l.arraystring3=o.arraystring3
    AND l.anotherarraytest1=o.anotherarraytest1
    AND l.anotherarraytest2=o.anotherarraytest2
    AND l.string=o.string
    AND l.recordappended1=o.recordappended1
    AND l.recordfloat=o.recordfloat
    AND l.recordstring2=o.recordstring2
    AND l.recordboolean2=o.recordboolean2""",
                    'description':'Diff of month of underlying table bob description: A test schema'},
                'bobdifffortnight':{'query':"""#standardSQL
SELECT
    o.scantime as origscantime,
    l.scantime as laterscantime,
    CASE
    WHEN o.integer IS NULL THEN 'Added'
    WHEN l.integer IS NULL THEN 'Deleted'
    WHEN o.integer = l.integer AND o.arrayinteger3 = l.arrayinteger3 AND o.arrayfoo = l.arrayfoo AND o.arraystring3 = l.arraystring3 AND o.anotherarraytest1 = l.anotherarraytest1 AND o.anotherarraytest2 = l.anotherarraytest2 AND o.string = l.string AND o.recordappended1 = l.recordappended1 AND o.recordfloat = l.recordfloat AND o.recordstring2 = l.recordstring2 AND o.recordboolean2 = l.recordboolean2 THEN 'Same'
    ELSE 'Updated'
  END AS action,
    o.integer as originteger,
    l.integer as laterinteger,
    case when o.integer = l.integer then 0 else 1 end as diffinteger,
    o.arrayinteger3 as origarrayinteger3,
    l.arrayinteger3 as laterarrayinteger3,
    case when o.arrayinteger3 = l.arrayinteger3 then 0 else 1 end as diffarrayinteger3,
    o.arrayfoo as origarrayfoo,
    l.arrayfoo as laterarrayfoo,
    case when o.arrayfoo = l.arrayfoo then 0 else 1 end as diffarrayfoo,
    o.arraystring3 as origarraystring3,
    l.arraystring3 as laterarraystring3,
    case when o.arraystring3 = l.arraystring3 then 0 else 1 end as diffarraystring3,
    o.anotherarraytest1 as origanotherarraytest1,
    l.anotherarraytest1 as lateranotherarraytest1,
    case when o.anotherarraytest1 = l.anotherarraytest1 then 0 else 1 end as diffanotherarraytest1,
    o.anotherarraytest2 as origanotherarraytest2,
    l.anotherarraytest2 as lateranotherarraytest2,
    case when o.anotherarraytest2 = l.anotherarraytest2 then 0 else 1 end as diffanotherarraytest2,
    o.string as origstring,
    l.string as laterstring,
    case when o.string = l.string then 0 else 1 end as diffstring,
    o.recordappended1 as origrecordappended1,
    l.recordappended1 as laterrecordappended1,
    case when o.recordappended1 = l.recordappended1 then 0 else 1 end as diffrecordappended1,
    o.recordfloat as origrecordfloat,
    l.recordfloat as laterrecordfloat,
    case when o.recordfloat = l.recordfloat then 0 else 1 end as diffrecordfloat,
    o.recordstring2 as origrecordstring2,
    l.recordstring2 as laterrecordstring2,
    case when o.recordstring2 = l.recordstring2 then 0 else 1 end as diffrecordstring2,
    o.recordboolean2 as origrecordboolean2,
    l.recordboolean2 as laterrecordboolean2,
    case when o.recordboolean2 = l.recordboolean2 then 0 else 1 end as diffrecordboolean2
  FROM (SELECT
     *
  FROM
    `foo.ar.bobdb`
  WHERE
    scantime = (
    SELECT
      MAX(_PARTITIONTIME)
    FROM
      `foo.ar.bob`
    WHERE
      scantime < (
      SELECT
        MAX(_PARTITIONTIME)
      FROM
        `foo.ar.bob`)
      AND
      _PARTITIONTIME < TIMESTAMP_SUB(CURRENT_TIMESTAMP(),INTERVAL 14 DAY) ) ) o
FULL OUTER JOIN (
  SELECT
     *
  FROM
    `foo.ar.bobdb`
  WHERE
    scantime =(
    SELECT
      MAX(_PARTITIONTIME)
    FROM
      `foo.ar.bob` )) l
ON
    l.integer = o.integer
    AND l.arrayinteger3=o.arrayinteger3
    AND l.arrayfoo=o.arrayfoo
    AND l.arraystring3=o.arraystring3
    AND l.anotherarraytest1=o.anotherarraytest1
    AND l.anotherarraytest2=o.anotherarraytest2
    AND l.string=o.string
    AND l.recordappended1=o.recordappended1
    AND l.recordfloat=o.recordfloat
    AND l.recordstring2=o.recordstring2
    AND l.recordboolean2=o.recordboolean2""",
                    'description':'Diff of fortnight of underlying table bob description: A test schema'}}
        for vi in views:
            expected = vexpected[vi['name']]['query'].splitlines(1)
            actual = vi['query'].splitlines(1)

            diff = difflib.unified_diff(expected, actual)

            print(''.join(diff))

            self.assertEqual(len(vi['query']), len(vexpected[vi['name']]['query']),
                             "Query len for view {} is not equal to what is expected\n:{}:\n:{}:".format(vi['name'],
                                                                                                     vi['query'],
                                                                                                     vexpected[
                                                                                                         vi['name']][
                                                                                                         'query']))
            self.assertEqual(vi['query'],vexpected[vi['name']]['query'],"Query for view {} is not equal to what is expected\n:{}:\n:{}:".format(vi['name'],vi['query'],vexpected[vi['name']]['query']))
            self.assertEqual(vi['description'],vexpected[vi['name']]['description'],"Description for view {} is not equal to what is expected\n:{}:\n:{}:".format(vi['name'],vi['description'],vexpected[vi['name']]['description']))
            
        
    def test_calc_field_depth(self):
        toTest = [{"name":'string',
                          "type":'STRING',
                          "description":None,
                          "mode":'NULLABLE'},
                        {"name":'integer',
                          "type":'INTEGER',
                          "description":None,
                          "mode":'NULLABLE'},
                         {"name":'float',
                          "type":'FLOAT',
                          "description":None,
                          "mode":'NULLABLE'},
                        {"name":'boolean',
                          "type":'BOOLEAN',
                          "description":None,
                          "mode":'NULLABLE'}, 
                        {"name":'record',
                          "type":'RECORD',
                          "description":None,
                          "mode":'NULLABLE',
                          "fields":
                              [{"name":'string2',
                                  "type":'STRING',
                                  "description":None,
                                  "mode":'NULLABLE'}, 
                                 {"name":'float',
                                  "type":'FLOAT',
                                  "description":None,
                                  "mode":'NULLABLE'},
                                 {"name":'integer2',
                                  "type":'INTEGER',
                                  "description":None,
                                  "mode":'NULLABLE'},
                                 {"name":'boolean2',
                                  "type":'BOOLEAN',
                                  "description":None,
                                  "mode":'NULLABLE'},
                                  {"name":'record',
                                   "type":'RECORD',
                                   "description":None,
                                   "mode":'NULLABLE',
                                   "fields":
                                       [{"name":'string2',
                                          "type":'STRING',
                                          "description":None,
                                          "mode":'NULLABLE'},
                                          {"name":'record',
                                           "type":'RECORD',
                                           "description":None,
                                           "mode":'NULLABLE',
                                           "fields":
                                              [{"name":'string2',
                                              "type":'STRING',
                                              "description":None,
                                              "mode":'NULLABLE'
                                              }] 
                                           }
                                        ]
                                   }]
                        },
                        {"name":'array',
                          "type":'RECORD',
                          "description":None,
                          "mode":'REPEATED',
                          "fields":[
                                 {"name":'string3',
                                  "type":'STRING',
                                  "description":None,
                                  "mode":'NULLABLE'}, 
                                 {"name":'integer3',
                                  "type":'INTEGER',
                                  "description":None,
                                  "mode":'NULLABLE'}
                                  ]} 
                         ]
        depth = bqtools.calc_field_depth(toTest)
        self.assertEqual(depth,3,"measured field depth should be 3")
        bqtools.trunc_field_depth(toTest,2)
        depth=bqtools.calc_field_depth(toTest)
        self.assertEqual(depth,2,"measured field depth should be 2 is {}".format(depth))
        depth = bqtools.calc_field_depth(self.monsterSchema['schema']['fields'])
        self.assertEqual(depth,13,"measured field depth should be 13 is {}".format(depth))
        newMonster=copy.deepcopy(self.monsterSchema)
        yamonster = bqtools.trunc_field_depth(newMonster['schema']['fields'],10)
        depth = bqtools.calc_field_depth(newMonster['schema']['fields'])
        self.assertEqual(depth,10,"measured field depth should be 10 is {}".format(depth))
        depth = bqtools.calc_field_depth(yamonster)
        self.assertEqual(depth,10,"measured field depth should be 10 is {}".format(depth))
        
    
 
def main(argv):
    unittest.main()

if __name__ == '__main__':
    main(sys.argv)
